Class: Aws::Macie2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Macie2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-macie2/client.rb,
sig/client.rbs
Overview
An API client for Macie2. To construct a client, you need to configure a :region and :credentials.
client = Aws::Macie2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptInvitationResponseSuccess, _BatchGetCustomDataIdentifiersResponseSuccess, _BatchUpdateAutomatedDiscoveryAccountsResponseSuccess, _CreateAllowListResponseSuccess, _CreateClassificationJobResponseSuccess, _CreateCustomDataIdentifierResponseSuccess, _CreateFindingsFilterResponseSuccess, _CreateInvitationsResponseSuccess, _CreateMemberResponseSuccess, _CreateSampleFindingsResponseSuccess, _DeclineInvitationsResponseSuccess, _DeleteAllowListResponseSuccess, _DeleteCustomDataIdentifierResponseSuccess, _DeleteFindingsFilterResponseSuccess, _DeleteInvitationsResponseSuccess, _DeleteMemberResponseSuccess, _DescribeBucketsResponseSuccess, _DescribeClassificationJobResponseSuccess, _DescribeOrganizationConfigurationResponseSuccess, _DisableMacieResponseSuccess, _DisableOrganizationAdminAccountResponseSuccess, _DisassociateFromAdministratorAccountResponseSuccess, _DisassociateFromMasterAccountResponseSuccess, _DisassociateMemberResponseSuccess, _EnableMacieResponseSuccess, _EnableOrganizationAdminAccountResponseSuccess, _GetAdministratorAccountResponseSuccess, _GetAllowListResponseSuccess, _GetAutomatedDiscoveryConfigurationResponseSuccess, _GetBucketStatisticsResponseSuccess, _GetClassificationExportConfigurationResponseSuccess, _GetClassificationScopeResponseSuccess, _GetCustomDataIdentifierResponseSuccess, _GetFindingStatisticsResponseSuccess, _GetFindingsFilterResponseSuccess, _GetFindingsPublicationConfigurationResponseSuccess, _GetFindingsResponseSuccess, _GetInvitationsCountResponseSuccess, _GetMacieSessionResponseSuccess, _GetMasterAccountResponseSuccess, _GetMemberResponseSuccess, _GetResourceProfileResponseSuccess, _GetRevealConfigurationResponseSuccess, _GetSensitiveDataOccurrencesAvailabilityResponseSuccess, _GetSensitiveDataOccurrencesResponseSuccess, _GetSensitivityInspectionTemplateResponseSuccess, _GetUsageStatisticsResponseSuccess, _GetUsageTotalsResponseSuccess, _ListAllowListsResponseSuccess, _ListAutomatedDiscoveryAccountsResponseSuccess, _ListClassificationJobsResponseSuccess, _ListClassificationScopesResponseSuccess, _ListCustomDataIdentifiersResponseSuccess, _ListFindingsFiltersResponseSuccess, _ListFindingsResponseSuccess, _ListInvitationsResponseSuccess, _ListManagedDataIdentifiersResponseSuccess, _ListMembersResponseSuccess, _ListOrganizationAdminAccountsResponseSuccess, _ListResourceProfileArtifactsResponseSuccess, _ListResourceProfileDetectionsResponseSuccess, _ListSensitivityInspectionTemplatesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutClassificationExportConfigurationResponseSuccess, _PutFindingsPublicationConfigurationResponseSuccess, _SearchResourcesResponseSuccess, _TagResourceResponseSuccess, _TestCustomDataIdentifierResponseSuccess, _UntagResourceResponseSuccess, _UpdateAllowListResponseSuccess, _UpdateAutomatedDiscoveryConfigurationResponseSuccess, _UpdateClassificationJobResponseSuccess, _UpdateClassificationScopeResponseSuccess, _UpdateFindingsFilterResponseSuccess, _UpdateMacieSessionResponseSuccess, _UpdateMemberSessionResponseSuccess, _UpdateOrganizationConfigurationResponseSuccess, _UpdateResourceProfileDetectionsResponseSuccess, _UpdateResourceProfileResponseSuccess, _UpdateRevealConfigurationResponseSuccess, _UpdateSensitivityInspectionTemplateResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
-
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
-
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
-
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
-
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
-
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
-
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
-
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
-
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
-
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
-
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
-
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
-
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
-
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
-
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
-
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
-
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
-
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
-
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
-
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
-
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
-
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
-
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
-
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
-
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
-
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
-
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
-
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
-
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
-
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
-
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
-
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
-
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account.
-
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that's associated with an Amazon Macie administrator account.
-
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
-
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
-
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
-
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
-
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
-
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
-
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
-
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
-
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
-
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
-
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
-
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
-
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
-
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
-
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
-
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
-
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
-
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
-
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
-
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
-
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
-
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
-
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
-
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
-
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
-
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
-
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
-
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
-
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
-
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
-
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
-
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-macie2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4196 4197 4198 |
# File 'lib/aws-sdk-macie2/client.rb', line 4196 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4199 4200 4201 |
# File 'lib/aws-sdk-macie2/client.rb', line 4199 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
85 |
# File 'sig/client.rbs', line 85
def accept_invitation: (
|
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
98 |
# File 'sig/client.rbs', line 98
def batch_get_custom_data_identifiers: (
|
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
108 |
# File 'sig/client.rbs', line 108
def batch_update_automated_discovery_accounts: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 |
# File 'lib/aws-sdk-macie2/client.rb', line 4056 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Macie2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-macie2' context[:gem_version] = '1.105.0' Seahorse::Client::Request.new(handlers, context) end |
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
124 |
# File 'sig/client.rbs', line 124
def create_allow_list: (
|
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
145 |
# File 'sig/client.rbs', line 145
def create_classification_job: (
|
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
191 |
# File 'sig/client.rbs', line 191
def create_custom_data_identifier: (
|
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
215 |
# File 'sig/client.rbs', line 215
def create_findings_filter: (
|
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
231 |
# File 'sig/client.rbs', line 231
def create_invitations: (
|
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
243 |
# File 'sig/client.rbs', line 243
def create_member: (
|
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
256 |
# File 'sig/client.rbs', line 256
def create_sample_findings: (
|
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
266 |
# File 'sig/client.rbs', line 266
def decline_invitations: (
|
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
275 |
# File 'sig/client.rbs', line 275
def delete_allow_list: (
|
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
285 |
# File 'sig/client.rbs', line 285
def delete_custom_data_identifier: (
|
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
294 |
# File 'sig/client.rbs', line 294
def delete_findings_filter: (
|
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
304 |
# File 'sig/client.rbs', line 304
def delete_invitations: (
|
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
313 |
# File 'sig/client.rbs', line 313
def delete_member: (
|
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
324 |
# File 'sig/client.rbs', line 324
def describe_buckets: (
|
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
368 |
# File 'sig/client.rbs', line 368
def describe_classification_job: (
|
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
379 |
# File 'sig/client.rbs', line 379
def describe_organization_configuration: (
|
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
387 |
# File 'sig/client.rbs', line 387
def disable_macie: (
|
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
395 |
# File 'sig/client.rbs', line 395
def disable_organization_admin_account: (
|
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
404 |
# File 'sig/client.rbs', line 404
def disassociate_from_administrator_account: (
|
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the
DisassociateFromAdministratorAccount operation.
412 |
# File 'sig/client.rbs', line 412
def disassociate_from_master_account: (
|
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
420 |
# File 'sig/client.rbs', line 420
def disassociate_member: (
|
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
429 |
# File 'sig/client.rbs', line 429
def enable_macie: (
|
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
440 |
# File 'sig/client.rbs', line 440
def enable_organization_admin_account: (
|
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
451 |
# File 'sig/client.rbs', line 451
def get_administrator_account: (
|
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
468 |
# File 'sig/client.rbs', line 468
def get_allow_list: (
|
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
484 |
# File 'sig/client.rbs', line 484
def get_automated_discovery_configuration: (
|
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
506 |
# File 'sig/client.rbs', line 506
def get_bucket_statistics: (
|
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
516 |
# File 'sig/client.rbs', line 516
def get_classification_export_configuration: (
|
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
527 |
# File 'sig/client.rbs', line 527
def get_classification_scope: (
|
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
548 |
# File 'sig/client.rbs', line 548
def get_custom_data_identifier: (
|
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
558 |
# File 'sig/client.rbs', line 558
def get_finding_statistics: (
|
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
574 |
# File 'sig/client.rbs', line 574
def get_findings: (
|
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
595 |
# File 'sig/client.rbs', line 595
def get_findings_filter: (
|
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
605 |
# File 'sig/client.rbs', line 605
def get_findings_publication_configuration: (
|
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
614 |
# File 'sig/client.rbs', line 614
def get_invitations_count: (
|
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
627 |
# File 'sig/client.rbs', line 627
def get_macie_session: (
|
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account. This operation has been replaced by the
GetAdministratorAccount operation.
636 |
# File 'sig/client.rbs', line 636
def get_master_account: (
|
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that's associated with an Amazon Macie administrator account.
653 |
# File 'sig/client.rbs', line 653
def get_member: (
|
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
666 |
# File 'sig/client.rbs', line 666
def get_resource_profile: (
|
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
677 |
# File 'sig/client.rbs', line 677
def get_reveal_configuration: (
|
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* finding_revealed
687 |
# File 'sig/client.rbs', line 687
def get_sensitive_data_occurrences: (
|
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
698 |
# File 'sig/client.rbs', line 698
def get_sensitive_data_occurrences_availability: (
|
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
712 |
# File 'sig/client.rbs', line 712
def get_sensitivity_inspection_template: (
|
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
724 |
# File 'sig/client.rbs', line 724
def get_usage_statistics: (
|
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
748 |
# File 'sig/client.rbs', line 748
def get_usage_totals: (
|
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
759 |
# File 'sig/client.rbs', line 759
def list_allow_lists: (
|
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
771 |
# File 'sig/client.rbs', line 771
def list_automated_discovery_accounts: (
|
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
784 |
# File 'sig/client.rbs', line 784
def list_classification_jobs: (
|
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
816 |
# File 'sig/client.rbs', line 816
def list_classification_scopes: (
|
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
828 |
# File 'sig/client.rbs', line 828
def list_custom_data_identifiers: (
|
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
840 |
# File 'sig/client.rbs', line 840
def list_findings: (
|
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
857 |
# File 'sig/client.rbs', line 857
def list_findings_filters: (
|
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
869 |
# File 'sig/client.rbs', line 869
def list_invitations: (
|
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
881 |
# File 'sig/client.rbs', line 881
def list_managed_data_identifiers: (
|
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
892 |
# File 'sig/client.rbs', line 892
def list_members: (
|
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
905 |
# File 'sig/client.rbs', line 905
def list_organization_admin_accounts: (
|
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
917 |
# File 'sig/client.rbs', line 917
def list_resource_profile_artifacts: (
|
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
929 |
# File 'sig/client.rbs', line 929
def list_resource_profile_detections: (
|
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
942 |
# File 'sig/client.rbs', line 942
def list_sensitivity_inspection_templates: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
953 |
# File 'sig/client.rbs', line 953
def list_tags_for_resource: (
|
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
963 |
# File 'sig/client.rbs', line 963
def put_classification_export_configuration: (
|
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
979 |
# File 'sig/client.rbs', line 979
def put_findings_publication_configuration: (
|
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
994 |
# File 'sig/client.rbs', line 994
def search_resources: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
1012 |
# File 'sig/client.rbs', line 1012
def tag_resource: (
|
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
1023 |
# File 'sig/client.rbs', line 1023
def test_custom_data_identifier: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
1036 |
# File 'sig/client.rbs', line 1036
def untag_resource: (
|
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
1048 |
# File 'sig/client.rbs', line 1048
def update_allow_list: (
|
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
1066 |
# File 'sig/client.rbs', line 1066
def update_automated_discovery_configuration: (
|
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
1076 |
# File 'sig/client.rbs', line 1076
def update_classification_job: (
|
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
1086 |
# File 'sig/client.rbs', line 1086
def update_classification_scope: (
|
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
1103 |
# File 'sig/client.rbs', line 1103
def update_findings_filter: (
|
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
1118 |
# File 'sig/client.rbs', line 1118
def update_macie_session: (
|
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
1128 |
# File 'sig/client.rbs', line 1128
def update_member_session: (
|
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
1138 |
# File 'sig/client.rbs', line 1138
def update_organization_configuration: (
|
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
1147 |
# File 'sig/client.rbs', line 1147
def update_resource_profile: (
|
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
1157 |
# File 'sig/client.rbs', line 1157
def update_resource_profile_detections: (
|
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
1174 |
# File 'sig/client.rbs', line 1174
def update_reveal_configuration: (
|
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
1190 |
# File 'sig/client.rbs', line 1190
def update_sensitivity_inspection_template: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| finding_revealed | #get_sensitive_data_occurrences | 2 | 60 |
1205 |
# File 'sig/client.rbs', line 1205
def wait_until: (:finding_revealed waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4170 4171 4172 |
# File 'lib/aws-sdk-macie2/client.rb', line 4170 def waiter_names waiters.keys end |