Method: Aws::Macie2::Types::BucketMetadata#unclassifiable_object_count

Defined in:
lib/aws-sdk-macie2/types.rb

#unclassifiable_object_countTypes::ObjectLevelStatistics

Provides information about the total storage size (in bytes) or number of objects that Amazon Macie can’t analyze in one or more S3 buckets. In a BucketMetadata or MatchingBucket object, this data is for a specific bucket. In a GetBucketStatisticsResponse object, this data is aggregated for all the buckets in the query results. If versioning is enabled for a bucket, storage size values are based on the size of the latest version of each applicable object in the bucket.



823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
# File 'lib/aws-sdk-macie2/types.rb', line 823

class  < Struct.new(
  :account_id,
  :allows_unencrypted_object_uploads,
  :automated_discovery_monitoring_status,
  :bucket_arn,
  :bucket_created_at,
  :bucket_name,
  :classifiable_object_count,
  :classifiable_size_in_bytes,
  :error_code,
  :error_message,
  :job_details,
  :last_automated_discovery_time,
  :last_updated,
  :object_count,
  :object_count_by_encryption_type,
  :public_access,
  :region,
  :replication_details,
  :sensitivity_score,
  :server_side_encryption,
  :shared_access,
  :size_in_bytes,
  :size_in_bytes_compressed,
  :tags,
  :unclassifiable_object_count,
  :unclassifiable_object_size_in_bytes,
  :versioning)
  SENSITIVE = []
  include Aws::Structure
end