Class: Aws::Macie2::Types::ClassificationExportConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Specifies where to store data classification results, and the encryption settings to use when storing results in that location. The location must be an S3 general purpose bucket.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_destinationTypes::S3Destination

Specifies an S3 bucket to store data classification results in, and the encryption settings to use when storing results in that bucket. The bucket must be an existing general purpose bucket. It can be a bucket in your own account or a bucket that another account owns. If another account owns the bucket, you must specify both the unique identifier for the account and the name of the bucket.



1089
1090
1091
1092
1093
# File 'lib/aws-sdk-macie2/types.rb', line 1089

class ClassificationExportConfiguration < Struct.new(
  :s3_destination)
  SENSITIVE = []
  include Aws::Structure
end