Class: Aws::Macie2::Types::ClassificationScopeSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about the classification scope for an Amazon Macie account. Macie uses the scope’s settings when it performs automated sensitive data discovery for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier the classification scope.

Returns:

  • (String)


1167
1168
1169
1170
1171
1172
# File 'lib/aws-sdk-macie2/types.rb', line 1167

class ClassificationScopeSummary < Struct.new(
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the classification scope.

Returns:

  • (String)


1167
1168
1169
1170
1171
1172
# File 'lib/aws-sdk-macie2/types.rb', line 1167

class ClassificationScopeSummary < Struct.new(
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end