Class: Aws::Macie2::Types::CreateInvitationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::CreateInvitationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies the settings for an Amazon Macie membership invitation. When you send an invitation, Macie notifies the recipient by creating an Health event for the recipient’s account and, if Macie is already enabled for the account, displaying an Accounts badge and notification on the recipient’s console. You can optionally notify the recipient by also sending the invitation as an email message.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#account_ids ⇒ Array<String>
1506 1507 1508 1509 1510 1511 1512 |
# File 'lib/aws-sdk-macie2/types.rb', line 1506 class CreateInvitationsRequest < Struct.new( :account_ids, :disable_email_notification, :message) SENSITIVE = [] include Aws::Structure end |
#disable_email_notification ⇒ Boolean
1506 1507 1508 1509 1510 1511 1512 |
# File 'lib/aws-sdk-macie2/types.rb', line 1506 class CreateInvitationsRequest < Struct.new( :account_ids, :disable_email_notification, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
1506 1507 1508 1509 1510 1511 1512 |
# File 'lib/aws-sdk-macie2/types.rb', line 1506 class CreateInvitationsRequest < Struct.new( :account_ids, :disable_email_notification, :message) SENSITIVE = [] include Aws::Structure end |