Class: Aws::Macie2::Types::CustomDataIdentifiers

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about custom data identifiers that produced a sensitive data finding, and the number of occurrences of the data that they detected for the finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detectionsArray<Types::CustomDetection>

Provides information about custom data identifiers that produced a sensitive data finding, and the number of occurrences of the data that each identifier detected.

Returns:



1706
1707
1708
1709
1710
1711
# File 'lib/aws-sdk-macie2/types.rb', line 1706

class CustomDataIdentifiers < Struct.new(
  :detections,
  :total_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_countInteger

Returns:

  • (Integer)


1706
1707
1708
1709
1710
1711
# File 'lib/aws-sdk-macie2/types.rb', line 1706

class CustomDataIdentifiers < Struct.new(
  :detections,
  :total_count)
  SENSITIVE = []
  include Aws::Structure
end