Class: Aws::Macie2::Types::Detection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about a type of sensitive data that Amazon Macie found in an S3 bucket while performing automated sensitive data discovery for an account. The information also specifies the custom or managed data identifier that detected the data. This information is available only if automated sensitive data discovery has been enabled for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Returns:

  • (String)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#countInteger

Returns:

  • (Integer)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#suppressedBoolean

Returns:

  • (Boolean)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of data identifier that detected a specific type of sensitive data in an S3 bucket. Possible values are:

Returns:

  • (String)


2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-macie2/types.rb', line 2153

class Detection < Struct.new(
  :arn,
  :count,
  :id,
  :name,
  :suppressed,
  :type)
  SENSITIVE = []
  include Aws::Structure
end