Class: Aws::Macie2::Types::DomainDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::DomainDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the domain name of the device that an entity used to perform an action on an affected resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#domain_name ⇒ String
2232 2233 2234 2235 2236 |
# File 'lib/aws-sdk-macie2/types.rb', line 2232 class DomainDetails < Struct.new( :domain_name) SENSITIVE = [] include Aws::Structure end |