Class: Aws::Macie2::Types::FederatedUser
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::FederatedUser
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about an identity that performed an action on an affected resource by using temporary security credentials. The credentials were obtained using the GetFederationToken operation of the Security Token Service (STS) API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #access_key_id ⇒ String
- #account_id ⇒ String
- #arn ⇒ String
- #principal_id ⇒ String
-
#session_context ⇒ Types::SessionContext
Provides information about a session that was created for an entity that performed an action by using temporary security credentials.
Instance Attribute Details
#access_key_id ⇒ String
2333 2334 2335 2336 2337 2338 2339 2340 2341 |
# File 'lib/aws-sdk-macie2/types.rb', line 2333 class FederatedUser < Struct.new( :access_key_id, :account_id, :arn, :principal_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
2333 2334 2335 2336 2337 2338 2339 2340 2341 |
# File 'lib/aws-sdk-macie2/types.rb', line 2333 class FederatedUser < Struct.new( :access_key_id, :account_id, :arn, :principal_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
2333 2334 2335 2336 2337 2338 2339 2340 2341 |
# File 'lib/aws-sdk-macie2/types.rb', line 2333 class FederatedUser < Struct.new( :access_key_id, :account_id, :arn, :principal_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
2333 2334 2335 2336 2337 2338 2339 2340 2341 |
# File 'lib/aws-sdk-macie2/types.rb', line 2333 class FederatedUser < Struct.new( :access_key_id, :account_id, :arn, :principal_id, :session_context) SENSITIVE = [] include Aws::Structure end |
#session_context ⇒ Types::SessionContext
Provides information about a session that was created for an entity that performed an action by using temporary security credentials.
2333 2334 2335 2336 2337 2338 2339 2340 2341 |
# File 'lib/aws-sdk-macie2/types.rb', line 2333 class FederatedUser < Struct.new( :access_key_id, :account_id, :arn, :principal_id, :session_context) SENSITIVE = [] include Aws::Structure end |