Class: Aws::Macie2::Types::GetClassificationExportConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about the current configuration settings for storing data classification results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::ClassificationExportConfiguration

Specifies where to store data classification results, and the encryption settings to use when storing results in that location. The location must be an S3 general purpose bucket.

Returns:



2852
2853
2854
2855
2856
# File 'lib/aws-sdk-macie2/types.rb', line 2852

class GetClassificationExportConfigurationResponse < Struct.new(
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end