Class: Aws::Macie2::Types::GetMacieSessionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about the status and configuration settings for an Amazon Macie account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

Returns:

  • (Time)


3207
3208
3209
3210
3211
3212
3213
3214
3215
# File 'lib/aws-sdk-macie2/types.rb', line 3207

class GetMacieSessionResponse < Struct.new(
  :created_at,
  :finding_publishing_frequency,
  :service_role,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#finding_publishing_frequencyString

The frequency with which Amazon Macie publishes updates to policy findings for an account. This includes publishing updates to Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events). For more information, see [Monitoring and processing findings] in the *Amazon Macie User Guide*. Valid values are:

[1]: docs.aws.amazon.com/macie/latest/user/findings-monitor.html

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
# File 'lib/aws-sdk-macie2/types.rb', line 3207

class GetMacieSessionResponse < Struct.new(
  :created_at,
  :finding_publishing_frequency,
  :service_role,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
# File 'lib/aws-sdk-macie2/types.rb', line 3207

class GetMacieSessionResponse < Struct.new(
  :created_at,
  :finding_publishing_frequency,
  :service_role,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of an Amazon Macie account. Valid values are:

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
# File 'lib/aws-sdk-macie2/types.rb', line 3207

class GetMacieSessionResponse < Struct.new(
  :created_at,
  :finding_publishing_frequency,
  :service_role,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

Returns:

  • (Time)


3207
3208
3209
3210
3211
3212
3213
3214
3215
# File 'lib/aws-sdk-macie2/types.rb', line 3207

class GetMacieSessionResponse < Struct.new(
  :created_at,
  :finding_publishing_frequency,
  :service_role,
  :status,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end