Class: Aws::Macie2::Types::GetUsageTotalsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides the results of a query that retrieved aggregated usage data for an Amazon Macie account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#time_rangeString

An inclusive time period that Amazon Macie usage data applies to. Possible values are:

Returns:

  • (String)


3592
3593
3594
3595
3596
3597
# File 'lib/aws-sdk-macie2/types.rb', line 3592

class GetUsageTotalsResponse < Struct.new(
  :time_range,
  :usage_totals)
  SENSITIVE = []
  include Aws::Structure
end

#usage_totalsArray<Types::UsageTotal>

Returns:



3592
3593
3594
3595
3596
3597
# File 'lib/aws-sdk-macie2/types.rb', line 3592

class GetUsageTotalsResponse < Struct.new(
  :time_range,
  :usage_totals)
  SENSITIVE = []
  include Aws::Structure
end