Class: Aws::Macie2::Types::KeyValuePair
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::KeyValuePair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the tags that are associated with an S3 bucket or object. Each tag consists of a required tag key and an associated tag value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#key ⇒ String
3968 3969 3970 3971 3972 3973 |
# File 'lib/aws-sdk-macie2/types.rb', line 3968 class KeyValuePair < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
3968 3969 3970 3971 3972 3973 |
# File 'lib/aws-sdk-macie2/types.rb', line 3968 class KeyValuePair < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |