Class: Aws::Macie2::Types::ListClassificationScopesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides the results of a request for information about the classification scope for an Amazon Macie account. Macie uses the scope's settings when it performs automated sensitive data discovery for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classification_scopesArray<Types::ClassificationScopeSummary>



4144
4145
4146
4147
4148
4149
# File 'lib/aws-sdk-macie2/types.rb', line 4144

class ListClassificationScopesResponse < Struct.new(
  :classification_scopes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specifies which page of results to return in a paginated response.

Returns:

  • (String)


4144
4145
4146
4147
4148
4149
# File 'lib/aws-sdk-macie2/types.rb', line 4144

class ListClassificationScopesResponse < Struct.new(
  :classification_scopes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end