Class: Aws::Macie2::Types::ListResourceProfileArtifactsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about objects that Amazon Macie selected from an S3 bucket while performing automated sensitive data discovery for an account. This information is available only if automated sensitive data discovery has been enabled for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#artifactsArray<Types::ResourceProfileArtifact>

Returns:



4493
4494
4495
4496
4497
4498
# File 'lib/aws-sdk-macie2/types.rb', line 4493

class ListResourceProfileArtifactsResponse < Struct.new(
  :artifacts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Returns:

  • (String)


4493
4494
4495
4496
4497
4498
# File 'lib/aws-sdk-macie2/types.rb', line 4493

class ListResourceProfileArtifactsResponse < Struct.new(
  :artifacts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end