Class: Aws::Macie2::Types::PutClassificationExportConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Specifies where to store data classification results, and the encryption settings to use when storing results in that location.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::ClassificationExportConfiguration

Specifies where to store data classification results, and the encryption settings to use when storing results in that location. The location must be an S3 general purpose bucket.



4996
4997
4998
4999
5000
# File 'lib/aws-sdk-macie2/types.rb', line 4996

class PutClassificationExportConfigurationRequest < Struct.new(
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end