Class: Aws::Macie2::Types::ResourceProfileArtifact
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::ResourceProfileArtifact
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about an S3 object that Amazon Macie selected for analysis while performing automated sensitive data discovery for an account, and the status and results of the analysis. This information is available only if automated sensitive data discovery has been enabled for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#arn ⇒ String
5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-macie2/types.rb', line 5146 class ResourceProfileArtifact < Struct.new( :arn, :classification_result_status, :sensitive) SENSITIVE = [] include Aws::Structure end |
#classification_result_status ⇒ String
5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-macie2/types.rb', line 5146 class ResourceProfileArtifact < Struct.new( :arn, :classification_result_status, :sensitive) SENSITIVE = [] include Aws::Structure end |
#sensitive ⇒ Boolean
5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-macie2/types.rb', line 5146 class ResourceProfileArtifact < Struct.new( :arn, :classification_result_status, :sensitive) SENSITIVE = [] include Aws::Structure end |