Class: Aws::Macie2::Types::ResourceStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides statistical data for sensitive data discovery metrics that apply to an S3 bucket that Amazon Macie monitors and analyzes for an account, if automated sensitive data discovery has been enabled for the account. The data captures the results of automated sensitive data discovery activities that Macie has performed for the bucket.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#total_bytes_classifiedInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_detectionsInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_detections_suppressedInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_classifiedInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_sensitiveInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_skippedInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_skipped_invalid_encryptionInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_skipped_invalid_kmsInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end

#total_items_skipped_permission_deniedInteger

Returns:

  • (Integer)


5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
# File 'lib/aws-sdk-macie2/types.rb', line 5189

class ResourceStatistics < Struct.new(
  :total_bytes_classified,
  :total_detections,
  :total_detections_suppressed,
  :total_items_classified,
  :total_items_sensitive,
  :total_items_skipped,
  :total_items_skipped_invalid_encryption,
  :total_items_skipped_invalid_kms,
  :total_items_skipped_permission_denied)
  SENSITIVE = []
  include Aws::Structure
end