Class: Aws::Macie2::Types::RevealConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Specifies the status of the Amazon Macie configuration for retrieving occurrences of sensitive data reported by findings, and the Key Management Service (KMS) key to use to encrypt sensitive data that’s retrieved. When you enable the configuration for the first time, your request must specify an KMS key. Otherwise, an error occurs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_idString

Returns:

  • (String)


5267
5268
5269
5270
5271
5272
# File 'lib/aws-sdk-macie2/types.rb', line 5267

class RevealConfiguration < Struct.new(
  :kms_key_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the configuration for retrieving occurrences of sensitive data reported by findings. Valid values are:

Returns:

  • (String)


5267
5268
5269
5270
5271
5272
# File 'lib/aws-sdk-macie2/types.rb', line 5267

class RevealConfiguration < Struct.new(
  :kms_key_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end