Class: Aws::Macie2::Types::S3JobDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::S3JobDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies which S3 buckets contain the objects that a classification job analyzes, and the scope of that analysis. The bucket specification can be static (bucketDefinitions) or dynamic (bucketCriteria). If it’s static, the job analyzes objects in the same predefined set of buckets each time the job runs. If it’s dynamic, the job analyzes objects in any buckets that match the specified criteria each time the job starts to run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_criteria ⇒ Types::S3BucketCriteriaForJob
Specifies property- and tag-based conditions that define criteria for including or excluding S3 buckets from a classification job.
- #bucket_definitions ⇒ Array<Types::S3BucketDefinitionForJob>
-
#scoping ⇒ Types::Scoping
Specifies one or more property- and tag-based conditions that define criteria for including or excluding S3 objects from a classification job.
Instance Attribute Details
#bucket_criteria ⇒ Types::S3BucketCriteriaForJob
Specifies property- and tag-based conditions that define criteria for including or excluding S3 buckets from a classification job. Exclude conditions take precedence over include conditions.
5513 5514 5515 5516 5517 5518 5519 |
# File 'lib/aws-sdk-macie2/types.rb', line 5513 class S3JobDefinition < Struct.new( :bucket_criteria, :bucket_definitions, :scoping) SENSITIVE = [] include Aws::Structure end |
#bucket_definitions ⇒ Array<Types::S3BucketDefinitionForJob>
5513 5514 5515 5516 5517 5518 5519 |
# File 'lib/aws-sdk-macie2/types.rb', line 5513 class S3JobDefinition < Struct.new( :bucket_criteria, :bucket_definitions, :scoping) SENSITIVE = [] include Aws::Structure end |
#scoping ⇒ Types::Scoping
Specifies one or more property- and tag-based conditions that define criteria for including or excluding S3 objects from a classification job. Exclude conditions take precedence over include conditions.
5513 5514 5515 5516 5517 5518 5519 |
# File 'lib/aws-sdk-macie2/types.rb', line 5513 class S3JobDefinition < Struct.new( :bucket_criteria, :bucket_definitions, :scoping) SENSITIVE = [] include Aws::Structure end |