Class: Aws::Macie2::Types::S3Object

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about the S3 object that a finding applies to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_arnString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#e_tagString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#extensionString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

Returns:

  • (Time)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#public_accessBoolean

Returns:

  • (Boolean)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#server_side_encryptionTypes::ServerSideEncryption

Provides information about the default server-side encryption settings for an S3 bucket or the encryption settings for an S3 object.



5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

Returns:

  • (Integer)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The storage class of the S3 object. Possible values are:

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::KeyValuePair>

Provides information about the tags that are associated with an S3 bucket or object. Each tag consists of a required tag key and an associated tag value.

Returns:



5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

Returns:

  • (String)


5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
# File 'lib/aws-sdk-macie2/types.rb', line 5568

class S3Object < Struct.new(
  :bucket_arn,
  :e_tag,
  :extension,
  :key,
  :last_modified,
  :path,
  :public_access,
  :server_side_encryption,
  :size,
  :storage_class,
  :tags,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end