Class: Aws::Macie2::Types::SearchResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::SearchResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies criteria for filtering, sorting, and paginating the results of a query for statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_criteria ⇒ Types::SearchResourcesBucketCriteria
Specifies property- and tag-based conditions that define filter criteria for including or excluding S3 buckets from the query results.
- #max_results ⇒ Integer
- #next_token ⇒ String
-
#sort_criteria ⇒ Types::SearchResourcesSortCriteria
Specifies criteria for sorting the results of a query for information about Amazon Web Services resources that Amazon Macie monitors and analyzes.
Instance Attribute Details
#bucket_criteria ⇒ Types::SearchResourcesBucketCriteria
Specifies property- and tag-based conditions that define filter criteria for including or excluding S3 buckets from the query results. Exclude conditions take precedence over include conditions.
5717 5718 5719 5720 5721 5722 5723 5724 |
# File 'lib/aws-sdk-macie2/types.rb', line 5717 class SearchResourcesRequest < Struct.new( :bucket_criteria, :max_results, :next_token, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
5717 5718 5719 5720 5721 5722 5723 5724 |
# File 'lib/aws-sdk-macie2/types.rb', line 5717 class SearchResourcesRequest < Struct.new( :bucket_criteria, :max_results, :next_token, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
5717 5718 5719 5720 5721 5722 5723 5724 |
# File 'lib/aws-sdk-macie2/types.rb', line 5717 class SearchResourcesRequest < Struct.new( :bucket_criteria, :max_results, :next_token, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Types::SearchResourcesSortCriteria
Specifies criteria for sorting the results of a query for information about Amazon Web Services resources that Amazon Macie monitors and analyzes.
5717 5718 5719 5720 5721 5722 5723 5724 |
# File 'lib/aws-sdk-macie2/types.rb', line 5717 class SearchResourcesRequest < Struct.new( :bucket_criteria, :max_results, :next_token, :sort_criteria) SENSITIVE = [] include Aws::Structure end |