Class: Aws::Macie2::Types::ServerSideEncryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::ServerSideEncryption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the default server-side encryption settings for an S3 bucket or the encryption settings for an S3 object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The server-side encryption algorithm that was used to encrypt an S3 object or is used by default to encrypt objects that are added to an S3 bucket.
- #kms_master_key_id ⇒ String
Instance Attribute Details
#encryption_type ⇒ String
The server-side encryption algorithm that was used to encrypt an S3 object or is used by default to encrypt objects that are added to an S3 bucket. Possible values are:
6000 6001 6002 6003 6004 6005 |
# File 'lib/aws-sdk-macie2/types.rb', line 6000 class ServerSideEncryption < Struct.new( :encryption_type, :kms_master_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_master_key_id ⇒ String
6000 6001 6002 6003 6004 6005 |
# File 'lib/aws-sdk-macie2/types.rb', line 6000 class ServerSideEncryption < Struct.new( :encryption_type, :kms_master_key_id) SENSITIVE = [] include Aws::Structure end |