Class: Aws::Macie2::Types::SessionIssuer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about the source and type of temporary security credentials that were issued to an entity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString



6090
6091
6092
6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-macie2/types.rb', line 6090

class SessionIssuer < Struct.new(
  :account_id,
  :arn,
  :principal_id,
  :type,
  :user_name)
  SENSITIVE = []
  include Aws::Structure
end

#arnString



6090
6091
6092
6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-macie2/types.rb', line 6090

class SessionIssuer < Struct.new(
  :account_id,
  :arn,
  :principal_id,
  :type,
  :user_name)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString



6090
6091
6092
6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-macie2/types.rb', line 6090

class SessionIssuer < Struct.new(
  :account_id,
  :arn,
  :principal_id,
  :type,
  :user_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString



6090
6091
6092
6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-macie2/types.rb', line 6090

class SessionIssuer < Struct.new(
  :account_id,
  :arn,
  :principal_id,
  :type,
  :user_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString



6090
6091
6092
6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-macie2/types.rb', line 6090

class SessionIssuer < Struct.new(
  :account_id,
  :arn,
  :principal_id,
  :type,
  :user_name)
  SENSITIVE = []
  include Aws::Structure
end