Class: Aws::Macie2::Types::SuppressDataIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::SuppressDataIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies a custom data identifier or managed data identifier that detected a type of sensitive data to exclude from an S3 bucket’s sensitivity score.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #id ⇒ String
-
#type ⇒ String
The type of data identifier that detected a specific type of sensitive data in an S3 bucket.
Instance Attribute Details
#id ⇒ String
6256 6257 6258 6259 6260 6261 |
# File 'lib/aws-sdk-macie2/types.rb', line 6256 class SuppressDataIdentifier < Struct.new( :id, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of data identifier that detected a specific type of sensitive data in an S3 bucket. Possible values are:
6256 6257 6258 6259 6260 6261 |
# File 'lib/aws-sdk-macie2/types.rb', line 6256 class SuppressDataIdentifier < Struct.new( :id, :type) SENSITIVE = [] include Aws::Structure end |