Class: Aws::Macie2::Types::UpdateAutomatedDiscoveryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::UpdateAutomatedDiscoveryConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Changes the configuration settings and status of automated sensitive data discovery for an organization in Amazon Macie or a standalone Macie account. To change additional settings, such as the managed data identifiers to use when analyzing data, update the sensitivity inspection template and classification scope for the organization’s Macie administrator account or the standalone account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_enable_organization_members ⇒ String
Specifies whether to automatically enable automated sensitive data discovery for accounts that are part of an organization in Amazon Macie.
-
#status ⇒ String
The status of the automated sensitive data discovery configuration for an organization in Amazon Macie or a standalone Macie account.
Instance Attribute Details
#auto_enable_organization_members ⇒ String
Specifies whether to automatically enable automated sensitive data discovery for accounts that are part of an organization in Amazon Macie. Valid values are:
6568 6569 6570 6571 6572 6573 |
# File 'lib/aws-sdk-macie2/types.rb', line 6568 class UpdateAutomatedDiscoveryConfigurationRequest < Struct.new( :auto_enable_organization_members, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the automated sensitive data discovery configuration for an organization in Amazon Macie or a standalone Macie account. Valid values are:
6568 6569 6570 6571 6572 6573 |
# File 'lib/aws-sdk-macie2/types.rb', line 6568 class UpdateAutomatedDiscoveryConfigurationRequest < Struct.new( :auto_enable_organization_members, :status) SENSITIVE = [] include Aws::Structure end |