Class: Aws::Macie2::Types::UpdateClassificationScopeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Specifies new classification scope settings for an Amazon Macie account. Macie uses these settings when it performs automated sensitive data discovery for the account. To update the settings, automated sensitive data discovery must be enabled for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

Returns:

  • (String)


6622
6623
6624
6625
6626
6627
# File 'lib/aws-sdk-macie2/types.rb', line 6622

class UpdateClassificationScopeRequest < Struct.new(
  :id,
  :s3)
  SENSITIVE = []
  include Aws::Structure
end

#s3Types::S3ClassificationScopeUpdate

Specifies changes to the list of S3 buckets that are excluded from automated sensitive data discovery for an Amazon Macie account.



6622
6623
6624
6625
6626
6627
# File 'lib/aws-sdk-macie2/types.rb', line 6622

class UpdateClassificationScopeRequest < Struct.new(
  :id,
  :s3)
  SENSITIVE = []
  include Aws::Structure
end