Class: Aws::Macie2::Types::UpdateResourceProfileDetectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Updates the sensitivity scoring settings for an S3 bucket that Amazon Macie monitors and analyzes for an account. The settings specify types of sensitive data to exclude from the sensitivity score that Macie calculates for the bucket. To update the settings, automated sensitive data discovery must be enabled for the account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

Returns:

  • (String)


6782
6783
6784
6785
6786
6787
# File 'lib/aws-sdk-macie2/types.rb', line 6782

class UpdateResourceProfileDetectionsRequest < Struct.new(
  :resource_arn,
  :suppress_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#suppress_data_identifiersArray<Types::SuppressDataIdentifier>

Returns:



6782
6783
6784
6785
6786
6787
# File 'lib/aws-sdk-macie2/types.rb', line 6782

class UpdateResourceProfileDetectionsRequest < Struct.new(
  :resource_arn,
  :suppress_data_identifiers)
  SENSITIVE = []
  include Aws::Structure
end