Class: Aws::Macie2::Types::UpdateRevealConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::UpdateRevealConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about updated configuration settings for retrieving occurrences of sensitive data reported by findings, and the status of the configuration for an Amazon Macie account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::RevealConfiguration
Specifies the status of the Amazon Macie configuration for retrieving occurrences of sensitive data reported by findings, and the Key Management Service (KMS) key to use to encrypt sensitive data that’s retrieved.
-
#retrieval_configuration ⇒ Types::RetrievalConfiguration
Provides information about the access method and settings that are used to retrieve occurrences of sensitive data reported by findings.
Instance Attribute Details
#configuration ⇒ Types::RevealConfiguration
Specifies the status of the Amazon Macie configuration for retrieving occurrences of sensitive data reported by findings, and the Key Management Service (KMS) key to use to encrypt sensitive data that’s retrieved. When you enable the configuration for the first time, your request must specify an KMS key. Otherwise, an error occurs.
6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-macie2/types.rb', line 6909 class UpdateRevealConfigurationResponse < Struct.new( :configuration, :retrieval_configuration) SENSITIVE = [] include Aws::Structure end |
#retrieval_configuration ⇒ Types::RetrievalConfiguration
Provides information about the access method and settings that are used to retrieve occurrences of sensitive data reported by findings.
6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-macie2/types.rb', line 6909 class UpdateRevealConfigurationResponse < Struct.new( :configuration, :retrieval_configuration) SENSITIVE = [] include Aws::Structure end |