Class: Aws::Macie2::Types::UpdateSensitivityInspectionTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::UpdateSensitivityInspectionTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies settings for the sensitivity inspection template for an Amazon Macie account. To update the settings, automated sensitive data discovery must be enabled for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #description ⇒ String
-
#excludes ⇒ Types::SensitivityInspectionTemplateExcludes
Specifies managed data identifiers to exclude (not use) when performing automated sensitive data discovery.
- #id ⇒ String
-
#includes ⇒ Types::SensitivityInspectionTemplateIncludes
Specifies the allow lists, custom data identifiers, and managed data identifiers to include (use) when performing automated sensitive data discovery.
Instance Attribute Details
#description ⇒ String
6954 6955 6956 6957 6958 6959 6960 6961 |
# File 'lib/aws-sdk-macie2/types.rb', line 6954 class UpdateSensitivityInspectionTemplateRequest < Struct.new( :description, :excludes, :id, :includes) SENSITIVE = [] include Aws::Structure end |
#excludes ⇒ Types::SensitivityInspectionTemplateExcludes
Specifies managed data identifiers to exclude (not use) when performing automated sensitive data discovery. For information about the managed data identifiers that Amazon Macie currently provides, see [Using managed data identifiers] in the *Amazon Macie User Guide*.
[1]: docs.aws.amazon.com/macie/latest/user/managed-data-identifiers.html
6954 6955 6956 6957 6958 6959 6960 6961 |
# File 'lib/aws-sdk-macie2/types.rb', line 6954 class UpdateSensitivityInspectionTemplateRequest < Struct.new( :description, :excludes, :id, :includes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
6954 6955 6956 6957 6958 6959 6960 6961 |
# File 'lib/aws-sdk-macie2/types.rb', line 6954 class UpdateSensitivityInspectionTemplateRequest < Struct.new( :description, :excludes, :id, :includes) SENSITIVE = [] include Aws::Structure end |
#includes ⇒ Types::SensitivityInspectionTemplateIncludes
Specifies the allow lists, custom data identifiers, and managed data identifiers to include (use) when performing automated sensitive data discovery. The configuration must specify at least one custom data identifier or managed data identifier. For information about the managed data identifiers that Amazon Macie currently provides, see [Using managed data identifiers] in the *Amazon Macie User Guide*.
[1]: docs.aws.amazon.com/macie/latest/user/managed-data-identifiers.html
6954 6955 6956 6957 6958 6959 6960 6961 |
# File 'lib/aws-sdk-macie2/types.rb', line 6954 class UpdateSensitivityInspectionTemplateRequest < Struct.new( :description, :excludes, :id, :includes) SENSITIVE = [] include Aws::Structure end |