Class: Aws::Macie2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Macie2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-macie2/client.rb
Overview
An API client for Macie2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Macie2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
-
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
-
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
-
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
-
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
-
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
-
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
-
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
-
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
-
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
-
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
-
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
-
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
-
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
-
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
-
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
-
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
-
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
-
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
-
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
-
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
-
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
-
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
-
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
-
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
-
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
-
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
-
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
-
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
-
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
-
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
-
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
-
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account.
-
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that’s associated with an Amazon Macie administrator account.
-
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
-
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
-
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
-
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
-
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
-
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
-
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
-
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
-
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
-
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
-
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
-
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
-
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
-
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
-
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
-
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
-
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
-
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
-
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
-
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
-
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
-
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
-
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
-
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
-
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
-
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
-
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
-
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
-
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
-
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
-
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
-
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-macie2/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4196 4197 4198 |
# File 'lib/aws-sdk-macie2/client.rb', line 4196 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4199 4200 4201 |
# File 'lib/aws-sdk-macie2/client.rb', line 4199 def errors_module Errors end |
Instance Method Details
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
500 501 502 503 |
# File 'lib/aws-sdk-macie2/client.rb', line 500 def accept_invitation(params = {}, = {}) req = build_request(:accept_invitation, params) req.send_request() end |
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
536 537 538 539 |
# File 'lib/aws-sdk-macie2/client.rb', line 536 def batch_get_custom_data_identifiers(params = {}, = {}) req = build_request(:batch_get_custom_data_identifiers, params) req.send_request() end |
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
571 572 573 574 |
# File 'lib/aws-sdk-macie2/client.rb', line 571 def batch_update_automated_discovery_accounts(params = {}, = {}) req = build_request(:batch_update_automated_discovery_accounts, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 |
# File 'lib/aws-sdk-macie2/client.rb', line 4056 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Macie2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-macie2' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
627 628 629 630 |
# File 'lib/aws-sdk-macie2/client.rb', line 627 def create_allow_list(params = {}, = {}) req = build_request(:create_allow_list, params) req.send_request() end |
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
813 814 815 816 |
# File 'lib/aws-sdk-macie2/client.rb', line 813 def create_classification_job(params = {}, = {}) req = build_request(:create_classification_job, params) req.send_request() end |
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
890 891 892 893 |
# File 'lib/aws-sdk-macie2/client.rb', line 890 def create_custom_data_identifier(params = {}, = {}) req = build_request(:create_custom_data_identifier, params) req.send_request() end |
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
961 962 963 964 |
# File 'lib/aws-sdk-macie2/client.rb', line 961 def create_findings_filter(params = {}, = {}) req = build_request(:create_findings_filter, params) req.send_request() end |
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
997 998 999 1000 |
# File 'lib/aws-sdk-macie2/client.rb', line 997 def create_invitations(params = {}, = {}) req = build_request(:create_invitations, params) req.send_request() end |
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-macie2/client.rb', line 1036 def create_member(params = {}, = {}) req = build_request(:create_member, params) req.send_request() end |
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
1057 1058 1059 1060 |
# File 'lib/aws-sdk-macie2/client.rb', line 1057 def create_sample_findings(params = {}, = {}) req = build_request(:create_sample_findings, params) req.send_request() end |
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-macie2/client.rb', line 1088 def decline_invitations(params = {}, = {}) req = build_request(:decline_invitations, params) req.send_request() end |
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
1112 1113 1114 1115 |
# File 'lib/aws-sdk-macie2/client.rb', line 1112 def delete_allow_list(params = {}, = {}) req = build_request(:delete_allow_list, params) req.send_request() end |
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
1133 1134 1135 1136 |
# File 'lib/aws-sdk-macie2/client.rb', line 1133 def delete_custom_data_identifier(params = {}, = {}) req = build_request(:delete_custom_data_identifier, params) req.send_request() end |
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
1154 1155 1156 1157 |
# File 'lib/aws-sdk-macie2/client.rb', line 1154 def delete_findings_filter(params = {}, = {}) req = build_request(:delete_findings_filter, params) req.send_request() end |
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
1185 1186 1187 1188 |
# File 'lib/aws-sdk-macie2/client.rb', line 1185 def delete_invitations(params = {}, = {}) req = build_request(:delete_invitations, params) req.send_request() end |
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
1207 1208 1209 1210 |
# File 'lib/aws-sdk-macie2/client.rb', line 1207 def delete_member(params = {}, = {}) req = build_request(:delete_member, params) req.send_request() end |
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1322 1323 1324 1325 |
# File 'lib/aws-sdk-macie2/client.rb', line 1322 def describe_buckets(params = {}, = {}) req = build_request(:describe_buckets, params) req.send_request() end |
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-macie2/client.rb', line 1440 def describe_classification_job(params = {}, = {}) req = build_request(:describe_classification_job, params) req.send_request() end |
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
1462 1463 1464 1465 |
# File 'lib/aws-sdk-macie2/client.rb', line 1462 def describe_organization_configuration(params = {}, = {}) req = build_request(:describe_organization_configuration, params) req.send_request() end |
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
1476 1477 1478 1479 |
# File 'lib/aws-sdk-macie2/client.rb', line 1476 def disable_macie(params = {}, = {}) req = build_request(:disable_macie, params) req.send_request() end |
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
1498 1499 1500 1501 |
# File 'lib/aws-sdk-macie2/client.rb', line 1498 def disable_organization_admin_account(params = {}, = {}) req = build_request(:disable_organization_admin_account, params) req.send_request() end |
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
1512 1513 1514 1515 |
# File 'lib/aws-sdk-macie2/client.rb', line 1512 def disassociate_from_administrator_account(params = {}, = {}) req = build_request(:disassociate_from_administrator_account, params) req.send_request() end |
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the <link linkend=“DisassociateFromAdministratorAccount” />
DisassociateFromAdministratorAccount</link> operation.
1529 1530 1531 1532 |
# File 'lib/aws-sdk-macie2/client.rb', line 1529 def disassociate_from_master_account(params = {}, = {}) req = build_request(:disassociate_from_master_account, params) req.send_request() end |
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
1551 1552 1553 1554 |
# File 'lib/aws-sdk-macie2/client.rb', line 1551 def disassociate_member(params = {}, = {}) req = build_request(:disassociate_member, params) req.send_request() end |
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
1591 1592 1593 1594 |
# File 'lib/aws-sdk-macie2/client.rb', line 1591 def enable_macie(params = {}, = {}) req = build_request(:enable_macie, params) req.send_request() end |
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
1618 1619 1620 1621 |
# File 'lib/aws-sdk-macie2/client.rb', line 1618 def enable_organization_admin_account(params = {}, = {}) req = build_request(:enable_organization_admin_account, params) req.send_request() end |
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
1641 1642 1643 1644 |
# File 'lib/aws-sdk-macie2/client.rb', line 1641 def get_administrator_account(params = {}, = {}) req = build_request(:get_administrator_account, params) req.send_request() end |
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
1688 1689 1690 1691 |
# File 'lib/aws-sdk-macie2/client.rb', line 1688 def get_allow_list(params = {}, = {}) req = build_request(:get_allow_list, params) req.send_request() end |
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
1720 1721 1722 1723 |
# File 'lib/aws-sdk-macie2/client.rb', line 1720 def get_automated_discovery_configuration(params = {}, = {}) req = build_request(:get_automated_discovery_configuration, params) req.send_request() end |
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
1804 1805 1806 1807 |
# File 'lib/aws-sdk-macie2/client.rb', line 1804 def get_bucket_statistics(params = {}, = {}) req = build_request(:get_bucket_statistics, params) req.send_request() end |
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
1827 1828 1829 1830 |
# File 'lib/aws-sdk-macie2/client.rb', line 1827 def get_classification_export_configuration(params = {}, = {}) req = build_request(:get_classification_export_configuration, params) req.send_request() end |
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
1859 1860 1861 1862 |
# File 'lib/aws-sdk-macie2/client.rb', line 1859 def get_classification_scope(params = {}, = {}) req = build_request(:get_classification_scope, params) req.send_request() end |
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
1914 1915 1916 1917 |
# File 'lib/aws-sdk-macie2/client.rb', line 1914 def get_custom_data_identifier(params = {}, = {}) req = build_request(:get_custom_data_identifier, params) req.send_request() end |
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
1971 1972 1973 1974 |
# File 'lib/aws-sdk-macie2/client.rb', line 1971 def get_finding_statistics(params = {}, = {}) req = build_request(:get_finding_statistics, params) req.send_request() end |
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
2177 2178 2179 2180 |
# File 'lib/aws-sdk-macie2/client.rb', line 2177 def get_findings(params = {}, = {}) req = build_request(:get_findings, params) req.send_request() end |
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
2229 2230 2231 2232 |
# File 'lib/aws-sdk-macie2/client.rb', line 2229 def get_findings_filter(params = {}, = {}) req = build_request(:get_findings_filter, params) req.send_request() end |
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
2250 2251 2252 2253 |
# File 'lib/aws-sdk-macie2/client.rb', line 2250 def get_findings_publication_configuration(params = {}, = {}) req = build_request(:get_findings_publication_configuration, params) req.send_request() end |
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
2270 2271 2272 2273 |
# File 'lib/aws-sdk-macie2/client.rb', line 2270 def get_invitations_count(params = {}, = {}) req = build_request(:get_invitations_count, params) req.send_request() end |
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
2298 2299 2300 2301 |
# File 'lib/aws-sdk-macie2/client.rb', line 2298 def get_macie_session(params = {}, = {}) req = build_request(:get_macie_session, params) req.send_request() end |
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account. This operation has been replaced by the <link linkend=“GetAdministratorAccount” />
GetAdministratorAccount</link> operation.
2324 2325 2326 2327 |
# File 'lib/aws-sdk-macie2/client.rb', line 2324 def get_master_account(params = {}, = {}) req = build_request(:get_master_account, params) req.send_request() end |
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that’s associated with an Amazon Macie administrator account.
2369 2370 2371 2372 |
# File 'lib/aws-sdk-macie2/client.rb', line 2369 def get_member(params = {}, = {}) req = build_request(:get_member, params) req.send_request() end |
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
2411 2412 2413 2414 |
# File 'lib/aws-sdk-macie2/client.rb', line 2411 def get_resource_profile(params = {}, = {}) req = build_request(:get_resource_profile, params) req.send_request() end |
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
2436 2437 2438 2439 |
# File 'lib/aws-sdk-macie2/client.rb', line 2436 def get_reveal_configuration(params = {}, = {}) req = build_request(:get_reveal_configuration, params) req.send_request() end |
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* finding_revealed
2474 2475 2476 2477 |
# File 'lib/aws-sdk-macie2/client.rb', line 2474 def get_sensitive_data_occurrences(params = {}, = {}) req = build_request(:get_sensitive_data_occurrences, params) req.send_request() end |
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
2505 2506 2507 2508 |
# File 'lib/aws-sdk-macie2/client.rb', line 2505 def get_sensitive_data_occurrences_availability(params = {}, = {}) req = build_request(:get_sensitive_data_occurrences_availability, params) req.send_request() end |
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
2547 2548 2549 2550 |
# File 'lib/aws-sdk-macie2/client.rb', line 2547 def get_sensitivity_inspection_template(params = {}, = {}) req = build_request(:get_sensitivity_inspection_template, params) req.send_request() end |
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2616 2617 2618 2619 |
# File 'lib/aws-sdk-macie2/client.rb', line 2616 def get_usage_statistics(params = {}, = {}) req = build_request(:get_usage_statistics, params) req.send_request() end |
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
2648 2649 2650 2651 |
# File 'lib/aws-sdk-macie2/client.rb', line 2648 def get_usage_totals(params = {}, = {}) req = build_request(:get_usage_totals, params) req.send_request() end |
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2689 2690 2691 2692 |
# File 'lib/aws-sdk-macie2/client.rb', line 2689 def list_allow_lists(params = {}, = {}) req = build_request(:list_allow_lists, params) req.send_request() end |
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2729 2730 2731 2732 |
# File 'lib/aws-sdk-macie2/client.rb', line 2729 def list_automated_discovery_accounts(params = {}, = {}) req = build_request(:list_automated_discovery_accounts, params) req.send_request() end |
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2823 2824 2825 2826 |
# File 'lib/aws-sdk-macie2/client.rb', line 2823 def list_classification_jobs(params = {}, = {}) req = build_request(:list_classification_jobs, params) req.send_request() end |
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2860 2861 2862 2863 |
# File 'lib/aws-sdk-macie2/client.rb', line 2860 def list_classification_scopes(params = {}, = {}) req = build_request(:list_classification_scopes, params) req.send_request() end |
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2900 2901 2902 2903 |
# File 'lib/aws-sdk-macie2/client.rb', line 2900 def list_custom_data_identifiers(params = {}, = {}) req = build_request(:list_custom_data_identifiers, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2959 2960 2961 2962 |
# File 'lib/aws-sdk-macie2/client.rb', line 2959 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3000 3001 3002 3003 |
# File 'lib/aws-sdk-macie2/client.rb', line 3000 def list_findings_filters(params = {}, = {}) req = build_request(:list_findings_filters, params) req.send_request() end |
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3039 3040 3041 3042 |
# File 'lib/aws-sdk-macie2/client.rb', line 3039 def list_invitations(params = {}, = {}) req = build_request(:list_invitations, params) req.send_request() end |
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3073 3074 3075 3076 |
# File 'lib/aws-sdk-macie2/client.rb', line 3073 def list_managed_data_identifiers(params = {}, = {}) req = build_request(:list_managed_data_identifiers, params) req.send_request() end |
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3121 3122 3123 3124 |
# File 'lib/aws-sdk-macie2/client.rb', line 3121 def list_members(params = {}, = {}) req = build_request(:list_members, params) req.send_request() end |
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3158 3159 3160 3161 |
# File 'lib/aws-sdk-macie2/client.rb', line 3158 def list_organization_admin_accounts(params = {}, = {}) req = build_request(:list_organization_admin_accounts, params) req.send_request() end |
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3196 3197 3198 3199 |
# File 'lib/aws-sdk-macie2/client.rb', line 3196 def list_resource_profile_artifacts(params = {}, = {}) req = build_request(:list_resource_profile_artifacts, params) req.send_request() end |
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3240 3241 3242 3243 |
# File 'lib/aws-sdk-macie2/client.rb', line 3240 def list_resource_profile_detections(params = {}, = {}) req = build_request(:list_resource_profile_detections, params) req.send_request() end |
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3277 3278 3279 3280 |
# File 'lib/aws-sdk-macie2/client.rb', line 3277 def list_sensitivity_inspection_templates(params = {}, = {}) req = build_request(:list_sensitivity_inspection_templates, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
3306 3307 3308 3309 |
# File 'lib/aws-sdk-macie2/client.rb', line 3306 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
3347 3348 3349 3350 |
# File 'lib/aws-sdk-macie2/client.rb', line 3347 def put_classification_export_configuration(params = {}, = {}) req = build_request(:put_classification_export_configuration, params) req.send_request() end |
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
3385 3386 3387 3388 |
# File 'lib/aws-sdk-macie2/client.rb', line 3385 def put_findings_publication_configuration(params = {}, = {}) req = build_request(:put_findings_publication_configuration, params) req.send_request() end |
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3504 3505 3506 3507 |
# File 'lib/aws-sdk-macie2/client.rb', line 3504 def search_resources(params = {}, = {}) req = build_request(:search_resources, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
3533 3534 3535 3536 |
# File 'lib/aws-sdk-macie2/client.rb', line 3533 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
3572 3573 3574 3575 |
# File 'lib/aws-sdk-macie2/client.rb', line 3572 def test_custom_data_identifier(params = {}, = {}) req = build_request(:test_custom_data_identifier, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
3597 3598 3599 3600 |
# File 'lib/aws-sdk-macie2/client.rb', line 3597 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
3644 3645 3646 3647 |
# File 'lib/aws-sdk-macie2/client.rb', line 3644 def update_allow_list(params = {}, = {}) req = build_request(:update_allow_list, params) req.send_request() end |
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
3675 3676 3677 3678 |
# File 'lib/aws-sdk-macie2/client.rb', line 3675 def update_automated_discovery_configuration(params = {}, = {}) req = build_request(:update_automated_discovery_configuration, params) req.send_request() end |
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
3700 3701 3702 3703 |
# File 'lib/aws-sdk-macie2/client.rb', line 3700 def update_classification_job(params = {}, = {}) req = build_request(:update_classification_job, params) req.send_request() end |
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
3731 3732 3733 3734 |
# File 'lib/aws-sdk-macie2/client.rb', line 3731 def update_classification_scope(params = {}, = {}) req = build_request(:update_classification_scope, params) req.send_request() end |
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
3797 3798 3799 3800 |
# File 'lib/aws-sdk-macie2/client.rb', line 3797 def update_findings_filter(params = {}, = {}) req = build_request(:update_findings_filter, params) req.send_request() end |
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
3832 3833 3834 3835 |
# File 'lib/aws-sdk-macie2/client.rb', line 3832 def update_macie_session(params = {}, = {}) req = build_request(:update_macie_session, params) req.send_request() end |
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
3858 3859 3860 3861 |
# File 'lib/aws-sdk-macie2/client.rb', line 3858 def update_member_session(params = {}, = {}) req = build_request(:update_member_session, params) req.send_request() end |
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
3880 3881 3882 3883 |
# File 'lib/aws-sdk-macie2/client.rb', line 3880 def update_organization_configuration(params = {}, = {}) req = build_request(:update_organization_configuration, params) req.send_request() end |
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
3904 3905 3906 3907 |
# File 'lib/aws-sdk-macie2/client.rb', line 3904 def update_resource_profile(params = {}, = {}) req = build_request(:update_resource_profile, params) req.send_request() end |
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
3933 3934 3935 3936 |
# File 'lib/aws-sdk-macie2/client.rb', line 3933 def update_resource_profile_detections(params = {}, = {}) req = build_request(:update_resource_profile_detections, params) req.send_request() end |
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
3992 3993 3994 3995 |
# File 'lib/aws-sdk-macie2/client.rb', line 3992 def update_reveal_configuration(params = {}, = {}) req = build_request(:update_reveal_configuration, params) req.send_request() end |
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
4047 4048 4049 4050 |
# File 'lib/aws-sdk-macie2/client.rb', line 4047 def update_sensitivity_inspection_template(params = {}, = {}) req = build_request(:update_sensitivity_inspection_template, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | —————- | ————————————— | ——– | ————- | | finding_revealed | #get_sensitive_data_occurrences | 2 | 60 |
4162 4163 4164 4165 4166 |
# File 'lib/aws-sdk-macie2/client.rb', line 4162 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4170 4171 4172 |
# File 'lib/aws-sdk-macie2/client.rb', line 4170 def waiter_names waiters.keys end |