Class: Aws::Macie2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Macie2::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-macie2/client.rb
Overview
An API client for Macie2. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Macie2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
-
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
-
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
-
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
-
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
-
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
-
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
-
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
-
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
-
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
-
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
-
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
-
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
-
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
-
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
-
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
-
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
-
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
-
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
-
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account.
-
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
-
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
-
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
-
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
-
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
-
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
-
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
-
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
-
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
-
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
-
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
-
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
-
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
-
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
-
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
-
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account.
-
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that’s associated with an Amazon Macie administrator account.
-
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
-
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
-
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
-
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
-
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
-
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
-
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
-
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
-
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
-
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
-
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
-
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
-
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
-
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
-
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
-
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
-
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
-
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
-
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
-
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
-
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
-
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
-
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
-
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
-
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
-
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
-
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
-
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
-
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
-
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
-
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
-
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
-
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
-
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
-
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-macie2/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4198 4199 4200 |
# File 'lib/aws-sdk-macie2/client.rb', line 4198 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4201 4202 4203 |
# File 'lib/aws-sdk-macie2/client.rb', line 4201 def errors_module Errors end |
Instance Method Details
#accept_invitation(params = {}) ⇒ Struct
Accepts an Amazon Macie membership invitation that was received from a specific account.
502 503 504 505 |
# File 'lib/aws-sdk-macie2/client.rb', line 502 def accept_invitation(params = {}, = {}) req = build_request(:accept_invitation, params) req.send_request() end |
#batch_get_custom_data_identifiers(params = {}) ⇒ Types::BatchGetCustomDataIdentifiersResponse
Retrieves information about one or more custom data identifiers.
538 539 540 541 |
# File 'lib/aws-sdk-macie2/client.rb', line 538 def batch_get_custom_data_identifiers(params = {}, = {}) req = build_request(:batch_get_custom_data_identifiers, params) req.send_request() end |
#batch_update_automated_discovery_accounts(params = {}) ⇒ Types::BatchUpdateAutomatedDiscoveryAccountsResponse
Changes the status of automated sensitive data discovery for one or more accounts.
573 574 575 576 |
# File 'lib/aws-sdk-macie2/client.rb', line 573 def batch_update_automated_discovery_accounts(params = {}, = {}) req = build_request(:batch_update_automated_discovery_accounts, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 |
# File 'lib/aws-sdk-macie2/client.rb', line 4058 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Macie2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-macie2' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#create_allow_list(params = {}) ⇒ Types::CreateAllowListResponse
Creates and defines the settings for an allow list.
629 630 631 632 |
# File 'lib/aws-sdk-macie2/client.rb', line 629 def create_allow_list(params = {}, = {}) req = build_request(:create_allow_list, params) req.send_request() end |
#create_classification_job(params = {}) ⇒ Types::CreateClassificationJobResponse
Creates and defines the settings for a classification job.
815 816 817 818 |
# File 'lib/aws-sdk-macie2/client.rb', line 815 def create_classification_job(params = {}, = {}) req = build_request(:create_classification_job, params) req.send_request() end |
#create_custom_data_identifier(params = {}) ⇒ Types::CreateCustomDataIdentifierResponse
Creates and defines the criteria and other settings for a custom data identifier.
892 893 894 895 |
# File 'lib/aws-sdk-macie2/client.rb', line 892 def create_custom_data_identifier(params = {}, = {}) req = build_request(:create_custom_data_identifier, params) req.send_request() end |
#create_findings_filter(params = {}) ⇒ Types::CreateFindingsFilterResponse
Creates and defines the criteria and other settings for a findings filter.
963 964 965 966 |
# File 'lib/aws-sdk-macie2/client.rb', line 963 def create_findings_filter(params = {}, = {}) req = build_request(:create_findings_filter, params) req.send_request() end |
#create_invitations(params = {}) ⇒ Types::CreateInvitationsResponse
Sends an Amazon Macie membership invitation to one or more accounts.
999 1000 1001 1002 |
# File 'lib/aws-sdk-macie2/client.rb', line 999 def create_invitations(params = {}, = {}) req = build_request(:create_invitations, params) req.send_request() end |
#create_member(params = {}) ⇒ Types::CreateMemberResponse
Associates an account with an Amazon Macie administrator account.
1038 1039 1040 1041 |
# File 'lib/aws-sdk-macie2/client.rb', line 1038 def create_member(params = {}, = {}) req = build_request(:create_member, params) req.send_request() end |
#create_sample_findings(params = {}) ⇒ Struct
Creates sample findings.
1059 1060 1061 1062 |
# File 'lib/aws-sdk-macie2/client.rb', line 1059 def create_sample_findings(params = {}, = {}) req = build_request(:create_sample_findings, params) req.send_request() end |
#decline_invitations(params = {}) ⇒ Types::DeclineInvitationsResponse
Declines Amazon Macie membership invitations that were received from specific accounts.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-macie2/client.rb', line 1090 def decline_invitations(params = {}, = {}) req = build_request(:decline_invitations, params) req.send_request() end |
#delete_allow_list(params = {}) ⇒ Struct
Deletes an allow list.
1114 1115 1116 1117 |
# File 'lib/aws-sdk-macie2/client.rb', line 1114 def delete_allow_list(params = {}, = {}) req = build_request(:delete_allow_list, params) req.send_request() end |
#delete_custom_data_identifier(params = {}) ⇒ Struct
Soft deletes a custom data identifier.
1135 1136 1137 1138 |
# File 'lib/aws-sdk-macie2/client.rb', line 1135 def delete_custom_data_identifier(params = {}, = {}) req = build_request(:delete_custom_data_identifier, params) req.send_request() end |
#delete_findings_filter(params = {}) ⇒ Struct
Deletes a findings filter.
1156 1157 1158 1159 |
# File 'lib/aws-sdk-macie2/client.rb', line 1156 def delete_findings_filter(params = {}, = {}) req = build_request(:delete_findings_filter, params) req.send_request() end |
#delete_invitations(params = {}) ⇒ Types::DeleteInvitationsResponse
Deletes Amazon Macie membership invitations that were received from specific accounts.
1187 1188 1189 1190 |
# File 'lib/aws-sdk-macie2/client.rb', line 1187 def delete_invitations(params = {}, = {}) req = build_request(:delete_invitations, params) req.send_request() end |
#delete_member(params = {}) ⇒ Struct
Deletes the association between an Amazon Macie administrator account and an account.
1209 1210 1211 1212 |
# File 'lib/aws-sdk-macie2/client.rb', line 1209 def delete_member(params = {}, = {}) req = build_request(:delete_member, params) req.send_request() end |
#describe_buckets(params = {}) ⇒ Types::DescribeBucketsResponse
Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1324 1325 1326 1327 |
# File 'lib/aws-sdk-macie2/client.rb', line 1324 def describe_buckets(params = {}, = {}) req = build_request(:describe_buckets, params) req.send_request() end |
#describe_classification_job(params = {}) ⇒ Types::DescribeClassificationJobResponse
Retrieves the status and settings for a classification job.
1442 1443 1444 1445 |
# File 'lib/aws-sdk-macie2/client.rb', line 1442 def describe_classification_job(params = {}, = {}) req = build_request(:describe_classification_job, params) req.send_request() end |
#describe_organization_configuration(params = {}) ⇒ Types::DescribeOrganizationConfigurationResponse
Retrieves the Amazon Macie configuration settings for an organization in Organizations.
1464 1465 1466 1467 |
# File 'lib/aws-sdk-macie2/client.rb', line 1464 def describe_organization_configuration(params = {}, = {}) req = build_request(:describe_organization_configuration, params) req.send_request() end |
#disable_macie(params = {}) ⇒ Struct
Disables Amazon Macie and deletes all settings and resources for a Macie account.
1478 1479 1480 1481 |
# File 'lib/aws-sdk-macie2/client.rb', line 1478 def disable_macie(params = {}, = {}) req = build_request(:disable_macie, params) req.send_request() end |
#disable_organization_admin_account(params = {}) ⇒ Struct
Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations.
1500 1501 1502 1503 |
# File 'lib/aws-sdk-macie2/client.rb', line 1500 def disable_organization_admin_account(params = {}, = {}) req = build_request(:disable_organization_admin_account, params) req.send_request() end |
#disassociate_from_administrator_account(params = {}) ⇒ Struct
Disassociates a member account from its Amazon Macie administrator account.
1514 1515 1516 1517 |
# File 'lib/aws-sdk-macie2/client.rb', line 1514 def disassociate_from_administrator_account(params = {}, = {}) req = build_request(:disassociate_from_administrator_account, params) req.send_request() end |
#disassociate_from_master_account(params = {}) ⇒ Struct
(Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the <link linkend=“DisassociateFromAdministratorAccount” />
DisassociateFromAdministratorAccount</link> operation.
1531 1532 1533 1534 |
# File 'lib/aws-sdk-macie2/client.rb', line 1531 def disassociate_from_master_account(params = {}, = {}) req = build_request(:disassociate_from_master_account, params) req.send_request() end |
#disassociate_member(params = {}) ⇒ Struct
Disassociates an Amazon Macie administrator account from a member account.
1553 1554 1555 1556 |
# File 'lib/aws-sdk-macie2/client.rb', line 1553 def disassociate_member(params = {}, = {}) req = build_request(:disassociate_member, params) req.send_request() end |
#enable_macie(params = {}) ⇒ Struct
Enables Amazon Macie and specifies the configuration settings for a Macie account.
1593 1594 1595 1596 |
# File 'lib/aws-sdk-macie2/client.rb', line 1593 def enable_macie(params = {}, = {}) req = build_request(:enable_macie, params) req.send_request() end |
#enable_organization_admin_account(params = {}) ⇒ Struct
Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations.
1620 1621 1622 1623 |
# File 'lib/aws-sdk-macie2/client.rb', line 1620 def enable_organization_admin_account(params = {}, = {}) req = build_request(:enable_organization_admin_account, params) req.send_request() end |
#get_administrator_account(params = {}) ⇒ Types::GetAdministratorAccountResponse
Retrieves information about the Amazon Macie administrator account for an account.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-macie2/client.rb', line 1643 def get_administrator_account(params = {}, = {}) req = build_request(:get_administrator_account, params) req.send_request() end |
#get_allow_list(params = {}) ⇒ Types::GetAllowListResponse
Retrieves the settings and status of an allow list.
1690 1691 1692 1693 |
# File 'lib/aws-sdk-macie2/client.rb', line 1690 def get_allow_list(params = {}, = {}) req = build_request(:get_allow_list, params) req.send_request() end |
#get_automated_discovery_configuration(params = {}) ⇒ Types::GetAutomatedDiscoveryConfigurationResponse
Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
1722 1723 1724 1725 |
# File 'lib/aws-sdk-macie2/client.rb', line 1722 def get_automated_discovery_configuration(params = {}, = {}) req = build_request(:get_automated_discovery_configuration, params) req.send_request() end |
#get_bucket_statistics(params = {}) ⇒ Types::GetBucketStatisticsResponse
Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account.
1806 1807 1808 1809 |
# File 'lib/aws-sdk-macie2/client.rb', line 1806 def get_bucket_statistics(params = {}, = {}) req = build_request(:get_bucket_statistics, params) req.send_request() end |
#get_classification_export_configuration(params = {}) ⇒ Types::GetClassificationExportConfigurationResponse
Retrieves the configuration settings for storing data classification results.
1829 1830 1831 1832 |
# File 'lib/aws-sdk-macie2/client.rb', line 1829 def get_classification_export_configuration(params = {}, = {}) req = build_request(:get_classification_export_configuration, params) req.send_request() end |
#get_classification_scope(params = {}) ⇒ Types::GetClassificationScopeResponse
Retrieves the classification scope settings for an account.
1861 1862 1863 1864 |
# File 'lib/aws-sdk-macie2/client.rb', line 1861 def get_classification_scope(params = {}, = {}) req = build_request(:get_classification_scope, params) req.send_request() end |
#get_custom_data_identifier(params = {}) ⇒ Types::GetCustomDataIdentifierResponse
Retrieves the criteria and other settings for a custom data identifier.
1916 1917 1918 1919 |
# File 'lib/aws-sdk-macie2/client.rb', line 1916 def get_custom_data_identifier(params = {}, = {}) req = build_request(:get_custom_data_identifier, params) req.send_request() end |
#get_finding_statistics(params = {}) ⇒ Types::GetFindingStatisticsResponse
Retrieves (queries) aggregated statistical data about findings.
1973 1974 1975 1976 |
# File 'lib/aws-sdk-macie2/client.rb', line 1973 def get_finding_statistics(params = {}, = {}) req = build_request(:get_finding_statistics, params) req.send_request() end |
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Retrieves the details of one or more findings.
2179 2180 2181 2182 |
# File 'lib/aws-sdk-macie2/client.rb', line 2179 def get_findings(params = {}, = {}) req = build_request(:get_findings, params) req.send_request() end |
#get_findings_filter(params = {}) ⇒ Types::GetFindingsFilterResponse
Retrieves the criteria and other settings for a findings filter.
2231 2232 2233 2234 |
# File 'lib/aws-sdk-macie2/client.rb', line 2231 def get_findings_filter(params = {}, = {}) req = build_request(:get_findings_filter, params) req.send_request() end |
#get_findings_publication_configuration(params = {}) ⇒ Types::GetFindingsPublicationConfigurationResponse
Retrieves the configuration settings for publishing findings to Security Hub.
2252 2253 2254 2255 |
# File 'lib/aws-sdk-macie2/client.rb', line 2252 def get_findings_publication_configuration(params = {}, = {}) req = build_request(:get_findings_publication_configuration, params) req.send_request() end |
#get_invitations_count(params = {}) ⇒ Types::GetInvitationsCountResponse
Retrieves the count of Amazon Macie membership invitations that were received by an account.
2272 2273 2274 2275 |
# File 'lib/aws-sdk-macie2/client.rb', line 2272 def get_invitations_count(params = {}, = {}) req = build_request(:get_invitations_count, params) req.send_request() end |
#get_macie_session(params = {}) ⇒ Types::GetMacieSessionResponse
Retrieves the status and configuration settings for an Amazon Macie account.
2300 2301 2302 2303 |
# File 'lib/aws-sdk-macie2/client.rb', line 2300 def get_macie_session(params = {}, = {}) req = build_request(:get_macie_session, params) req.send_request() end |
#get_master_account(params = {}) ⇒ Types::GetMasterAccountResponse
(Deprecated) Retrieves information about the Amazon Macie administrator account for an account. This operation has been replaced by the <link linkend=“GetAdministratorAccount” />
GetAdministratorAccount</link> operation.
2326 2327 2328 2329 |
# File 'lib/aws-sdk-macie2/client.rb', line 2326 def get_master_account(params = {}, = {}) req = build_request(:get_master_account, params) req.send_request() end |
#get_member(params = {}) ⇒ Types::GetMemberResponse
Retrieves information about an account that’s associated with an Amazon Macie administrator account.
2371 2372 2373 2374 |
# File 'lib/aws-sdk-macie2/client.rb', line 2371 def get_member(params = {}, = {}) req = build_request(:get_member, params) req.send_request() end |
#get_resource_profile(params = {}) ⇒ Types::GetResourceProfileResponse
Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket.
2413 2414 2415 2416 |
# File 'lib/aws-sdk-macie2/client.rb', line 2413 def get_resource_profile(params = {}, = {}) req = build_request(:get_resource_profile, params) req.send_request() end |
#get_reveal_configuration(params = {}) ⇒ Types::GetRevealConfigurationResponse
Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
2438 2439 2440 2441 |
# File 'lib/aws-sdk-macie2/client.rb', line 2438 def get_reveal_configuration(params = {}, = {}) req = build_request(:get_reveal_configuration, params) req.send_request() end |
#get_sensitive_data_occurrences(params = {}) ⇒ Types::GetSensitiveDataOccurrencesResponse
Retrieves occurrences of sensitive data reported by a finding.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* finding_revealed
2476 2477 2478 2479 |
# File 'lib/aws-sdk-macie2/client.rb', line 2476 def get_sensitive_data_occurrences(params = {}, = {}) req = build_request(:get_sensitive_data_occurrences, params) req.send_request() end |
#get_sensitive_data_occurrences_availability(params = {}) ⇒ Types::GetSensitiveDataOccurrencesAvailabilityResponse
Checks whether occurrences of sensitive data can be retrieved for a finding.
2507 2508 2509 2510 |
# File 'lib/aws-sdk-macie2/client.rb', line 2507 def get_sensitive_data_occurrences_availability(params = {}, = {}) req = build_request(:get_sensitive_data_occurrences_availability, params) req.send_request() end |
#get_sensitivity_inspection_template(params = {}) ⇒ Types::GetSensitivityInspectionTemplateResponse
Retrieves the settings for the sensitivity inspection template for an account.
2549 2550 2551 2552 |
# File 'lib/aws-sdk-macie2/client.rb', line 2549 def get_sensitivity_inspection_template(params = {}, = {}) req = build_request(:get_sensitivity_inspection_template, params) req.send_request() end |
#get_usage_statistics(params = {}) ⇒ Types::GetUsageStatisticsResponse
Retrieves (queries) quotas and aggregated usage data for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2618 2619 2620 2621 |
# File 'lib/aws-sdk-macie2/client.rb', line 2618 def get_usage_statistics(params = {}, = {}) req = build_request(:get_usage_statistics, params) req.send_request() end |
#get_usage_totals(params = {}) ⇒ Types::GetUsageTotalsResponse
Retrieves (queries) aggregated usage data for an account.
2650 2651 2652 2653 |
# File 'lib/aws-sdk-macie2/client.rb', line 2650 def get_usage_totals(params = {}, = {}) req = build_request(:get_usage_totals, params) req.send_request() end |
#list_allow_lists(params = {}) ⇒ Types::ListAllowListsResponse
Retrieves a subset of information about all the allow lists for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2691 2692 2693 2694 |
# File 'lib/aws-sdk-macie2/client.rb', line 2691 def list_allow_lists(params = {}, = {}) req = build_request(:list_allow_lists, params) req.send_request() end |
#list_automated_discovery_accounts(params = {}) ⇒ Types::ListAutomatedDiscoveryAccountsResponse
Retrieves the status of automated sensitive data discovery for one or more accounts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2731 2732 2733 2734 |
# File 'lib/aws-sdk-macie2/client.rb', line 2731 def list_automated_discovery_accounts(params = {}, = {}) req = build_request(:list_automated_discovery_accounts, params) req.send_request() end |
#list_classification_jobs(params = {}) ⇒ Types::ListClassificationJobsResponse
Retrieves a subset of information about one or more classification jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2825 2826 2827 2828 |
# File 'lib/aws-sdk-macie2/client.rb', line 2825 def list_classification_jobs(params = {}, = {}) req = build_request(:list_classification_jobs, params) req.send_request() end |
#list_classification_scopes(params = {}) ⇒ Types::ListClassificationScopesResponse
Retrieves a subset of information about the classification scope for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2862 2863 2864 2865 |
# File 'lib/aws-sdk-macie2/client.rb', line 2862 def list_classification_scopes(params = {}, = {}) req = build_request(:list_classification_scopes, params) req.send_request() end |
#list_custom_data_identifiers(params = {}) ⇒ Types::ListCustomDataIdentifiersResponse
Retrieves a subset of information about the custom data identifiers for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2902 2903 2904 2905 |
# File 'lib/aws-sdk-macie2/client.rb', line 2902 def list_custom_data_identifiers(params = {}, = {}) req = build_request(:list_custom_data_identifiers, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a subset of information about one or more findings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2961 2962 2963 2964 |
# File 'lib/aws-sdk-macie2/client.rb', line 2961 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_findings_filters(params = {}) ⇒ Types::ListFindingsFiltersResponse
Retrieves a subset of information about all the findings filters for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3002 3003 3004 3005 |
# File 'lib/aws-sdk-macie2/client.rb', line 3002 def list_findings_filters(params = {}, = {}) req = build_request(:list_findings_filters, params) req.send_request() end |
#list_invitations(params = {}) ⇒ Types::ListInvitationsResponse
Retrieves information about Amazon Macie membership invitations that were received by an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3041 3042 3043 3044 |
# File 'lib/aws-sdk-macie2/client.rb', line 3041 def list_invitations(params = {}, = {}) req = build_request(:list_invitations, params) req.send_request() end |
#list_managed_data_identifiers(params = {}) ⇒ Types::ListManagedDataIdentifiersResponse
Retrieves information about all the managed data identifiers that Amazon Macie currently provides.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3075 3076 3077 3078 |
# File 'lib/aws-sdk-macie2/client.rb', line 3075 def list_managed_data_identifiers(params = {}, = {}) req = build_request(:list_managed_data_identifiers, params) req.send_request() end |
#list_members(params = {}) ⇒ Types::ListMembersResponse
Retrieves information about the accounts that are associated with an Amazon Macie administrator account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3123 3124 3125 3126 |
# File 'lib/aws-sdk-macie2/client.rb', line 3123 def list_members(params = {}, = {}) req = build_request(:list_members, params) req.send_request() end |
#list_organization_admin_accounts(params = {}) ⇒ Types::ListOrganizationAdminAccountsResponse
Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3160 3161 3162 3163 |
# File 'lib/aws-sdk-macie2/client.rb', line 3160 def list_organization_admin_accounts(params = {}, = {}) req = build_request(:list_organization_admin_accounts, params) req.send_request() end |
#list_resource_profile_artifacts(params = {}) ⇒ Types::ListResourceProfileArtifactsResponse
Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3198 3199 3200 3201 |
# File 'lib/aws-sdk-macie2/client.rb', line 3198 def list_resource_profile_artifacts(params = {}, = {}) req = build_request(:list_resource_profile_artifacts, params) req.send_request() end |
#list_resource_profile_detections(params = {}) ⇒ Types::ListResourceProfileDetectionsResponse
Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3242 3243 3244 3245 |
# File 'lib/aws-sdk-macie2/client.rb', line 3242 def list_resource_profile_detections(params = {}, = {}) req = build_request(:list_resource_profile_detections, params) req.send_request() end |
#list_sensitivity_inspection_templates(params = {}) ⇒ Types::ListSensitivityInspectionTemplatesResponse
Retrieves a subset of information about the sensitivity inspection template for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3279 3280 3281 3282 |
# File 'lib/aws-sdk-macie2/client.rb', line 3279 def list_sensitivity_inspection_templates(params = {}, = {}) req = build_request(:list_sensitivity_inspection_templates, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Macie resource.
3308 3309 3310 3311 |
# File 'lib/aws-sdk-macie2/client.rb', line 3308 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_classification_export_configuration(params = {}) ⇒ Types::PutClassificationExportConfigurationResponse
Adds or updates the configuration settings for storing data classification results.
3349 3350 3351 3352 |
# File 'lib/aws-sdk-macie2/client.rb', line 3349 def put_classification_export_configuration(params = {}, = {}) req = build_request(:put_classification_export_configuration, params) req.send_request() end |
#put_findings_publication_configuration(params = {}) ⇒ Struct
Updates the configuration settings for publishing findings to Security Hub.
3387 3388 3389 3390 |
# File 'lib/aws-sdk-macie2/client.rb', line 3387 def put_findings_publication_configuration(params = {}, = {}) req = build_request(:put_findings_publication_configuration, params) req.send_request() end |
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3506 3507 3508 3509 |
# File 'lib/aws-sdk-macie2/client.rb', line 3506 def search_resources(params = {}, = {}) req = build_request(:search_resources, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource.
3535 3536 3537 3538 |
# File 'lib/aws-sdk-macie2/client.rb', line 3535 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_custom_data_identifier(params = {}) ⇒ Types::TestCustomDataIdentifierResponse
Tests criteria for a custom data identifier.
3574 3575 3576 3577 |
# File 'lib/aws-sdk-macie2/client.rb', line 3574 def test_custom_data_identifier(params = {}, = {}) req = build_request(:test_custom_data_identifier, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Macie resource.
3599 3600 3601 3602 |
# File 'lib/aws-sdk-macie2/client.rb', line 3599 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_allow_list(params = {}) ⇒ Types::UpdateAllowListResponse
Updates the settings for an allow list.
3646 3647 3648 3649 |
# File 'lib/aws-sdk-macie2/client.rb', line 3646 def update_allow_list(params = {}, = {}) req = build_request(:update_allow_list, params) req.send_request() end |
#update_automated_discovery_configuration(params = {}) ⇒ Struct
Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account.
3677 3678 3679 3680 |
# File 'lib/aws-sdk-macie2/client.rb', line 3677 def update_automated_discovery_configuration(params = {}, = {}) req = build_request(:update_automated_discovery_configuration, params) req.send_request() end |
#update_classification_job(params = {}) ⇒ Struct
Changes the status of a classification job.
3702 3703 3704 3705 |
# File 'lib/aws-sdk-macie2/client.rb', line 3702 def update_classification_job(params = {}, = {}) req = build_request(:update_classification_job, params) req.send_request() end |
#update_classification_scope(params = {}) ⇒ Struct
Updates the classification scope settings for an account.
3733 3734 3735 3736 |
# File 'lib/aws-sdk-macie2/client.rb', line 3733 def update_classification_scope(params = {}, = {}) req = build_request(:update_classification_scope, params) req.send_request() end |
#update_findings_filter(params = {}) ⇒ Types::UpdateFindingsFilterResponse
Updates the criteria and other settings for a findings filter.
3799 3800 3801 3802 |
# File 'lib/aws-sdk-macie2/client.rb', line 3799 def update_findings_filter(params = {}, = {}) req = build_request(:update_findings_filter, params) req.send_request() end |
#update_macie_session(params = {}) ⇒ Struct
Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account.
3834 3835 3836 3837 |
# File 'lib/aws-sdk-macie2/client.rb', line 3834 def update_macie_session(params = {}, = {}) req = build_request(:update_macie_session, params) req.send_request() end |
#update_member_session(params = {}) ⇒ Struct
Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account.
3860 3861 3862 3863 |
# File 'lib/aws-sdk-macie2/client.rb', line 3860 def update_member_session(params = {}, = {}) req = build_request(:update_member_session, params) req.send_request() end |
#update_organization_configuration(params = {}) ⇒ Struct
Updates the Amazon Macie configuration settings for an organization in Organizations.
3882 3883 3884 3885 |
# File 'lib/aws-sdk-macie2/client.rb', line 3882 def update_organization_configuration(params = {}, = {}) req = build_request(:update_organization_configuration, params) req.send_request() end |
#update_resource_profile(params = {}) ⇒ Struct
Updates the sensitivity score for an S3 bucket.
3906 3907 3908 3909 |
# File 'lib/aws-sdk-macie2/client.rb', line 3906 def update_resource_profile(params = {}, = {}) req = build_request(:update_resource_profile, params) req.send_request() end |
#update_resource_profile_detections(params = {}) ⇒ Struct
Updates the sensitivity scoring settings for an S3 bucket.
3935 3936 3937 3938 |
# File 'lib/aws-sdk-macie2/client.rb', line 3935 def update_resource_profile_detections(params = {}, = {}) req = build_request(:update_resource_profile_detections, params) req.send_request() end |
#update_reveal_configuration(params = {}) ⇒ Types::UpdateRevealConfigurationResponse
Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings.
3994 3995 3996 3997 |
# File 'lib/aws-sdk-macie2/client.rb', line 3994 def update_reveal_configuration(params = {}, = {}) req = build_request(:update_reveal_configuration, params) req.send_request() end |
#update_sensitivity_inspection_template(params = {}) ⇒ Struct
Updates the settings for the sensitivity inspection template for an account.
4049 4050 4051 4052 |
# File 'lib/aws-sdk-macie2/client.rb', line 4049 def update_sensitivity_inspection_template(params = {}, = {}) req = build_request(:update_sensitivity_inspection_template, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | —————- | ————————————— | ——– | ————- | | finding_revealed | #get_sensitive_data_occurrences | 2 | 60 |
4164 4165 4166 4167 4168 |
# File 'lib/aws-sdk-macie2/client.rb', line 4164 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4172 4173 4174 |
# File 'lib/aws-sdk-macie2/client.rb', line 4172 def waiter_names waiters.keys end |