Class: Aws::Macie2::Types::GetClassificationExportConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::GetClassificationExportConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the current configuration settings for storing data classification results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::ClassificationExportConfiguration
Specifies where to store data classification results, and the encryption settings to use when storing results in that location.
Instance Attribute Details
#configuration ⇒ Types::ClassificationExportConfiguration
Specifies where to store data classification results, and the encryption settings to use when storing results in that location. The location must be an S3 general purpose bucket.
2856 2857 2858 2859 2860 |
# File 'lib/aws-sdk-macie2/types.rb', line 2856 class GetClassificationExportConfigurationResponse < Struct.new( :configuration) SENSITIVE = [] include Aws::Structure end |