Class: Aws::Macie2::Types::GetMacieSessionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::GetMacieSessionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the status and configuration settings for an Amazon Macie account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #created_at ⇒ Time
-
#finding_publishing_frequency ⇒ String
The frequency with which Amazon Macie publishes updates to policy findings for an account.
- #service_role ⇒ String
-
#status ⇒ String
The status of an Amazon Macie account.
- #updated_at ⇒ Time
Instance Attribute Details
#created_at ⇒ Time
3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-macie2/types.rb', line 3207 class GetMacieSessionResponse < Struct.new( :created_at, :finding_publishing_frequency, :service_role, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#finding_publishing_frequency ⇒ String
The frequency with which Amazon Macie publishes updates to policy findings for an account. This includes publishing updates to Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events). For more information, see [Monitoring and processing findings] in the *Amazon Macie User Guide*. Valid values are:
[1]: docs.aws.amazon.com/macie/latest/user/findings-monitor.html
3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-macie2/types.rb', line 3207 class GetMacieSessionResponse < Struct.new( :created_at, :finding_publishing_frequency, :service_role, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-macie2/types.rb', line 3207 class GetMacieSessionResponse < Struct.new( :created_at, :finding_publishing_frequency, :service_role, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of an Amazon Macie account. Valid values are:
3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-macie2/types.rb', line 3207 class GetMacieSessionResponse < Struct.new( :created_at, :finding_publishing_frequency, :service_role, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
3207 3208 3209 3210 3211 3212 3213 3214 3215 |
# File 'lib/aws-sdk-macie2/types.rb', line 3207 class GetMacieSessionResponse < Struct.new( :created_at, :finding_publishing_frequency, :service_role, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |