Class: Aws::Macie2::Types::ListResourceProfileArtifactsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::ListResourceProfileArtifactsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about objects that Amazon Macie selected from an S3 bucket while performing automated sensitive data discovery for an account. This information is available only if automated sensitive data discovery has been enabled for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#artifacts ⇒ Array<Types::ResourceProfileArtifact>
4493 4494 4495 4496 4497 4498 |
# File 'lib/aws-sdk-macie2/types.rb', line 4493 class ListResourceProfileArtifactsResponse < Struct.new( :artifacts, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
4493 4494 4495 4496 4497 4498 |
# File 'lib/aws-sdk-macie2/types.rb', line 4493 class ListResourceProfileArtifactsResponse < Struct.new( :artifacts, :next_token) SENSITIVE = [] include Aws::Structure end |