Class: Aws::Macie2::Types::PutClassificationExportConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie2/types.rb

Overview

Provides information about updated settings for storing data classification results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::ClassificationExportConfiguration

Specifies where to store data classification results, and the encryption settings to use when storing results in that location. The location must be an S3 general purpose bucket.



5013
5014
5015
5016
5017
# File 'lib/aws-sdk-macie2/types.rb', line 5013

class PutClassificationExportConfigurationResponse < Struct.new(
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end