Class: Aws::Macie2::Types::ReplicationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::ReplicationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about settings that define whether one or more objects in an S3 bucket are replicated to S3 buckets for other Amazon Web Services accounts and, if so, which accounts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#replicated ⇒ Boolean
5107 5108 5109 5110 5111 5112 5113 |
# File 'lib/aws-sdk-macie2/types.rb', line 5107 class ReplicationDetails < Struct.new( :replicated, :replicated_externally, :replication_accounts) SENSITIVE = [] include Aws::Structure end |
#replicated_externally ⇒ Boolean
5107 5108 5109 5110 5111 5112 5113 |
# File 'lib/aws-sdk-macie2/types.rb', line 5107 class ReplicationDetails < Struct.new( :replicated, :replicated_externally, :replication_accounts) SENSITIVE = [] include Aws::Structure end |
#replication_accounts ⇒ Array<String>
5107 5108 5109 5110 5111 5112 5113 |
# File 'lib/aws-sdk-macie2/types.rb', line 5107 class ReplicationDetails < Struct.new( :replicated, :replicated_externally, :replication_accounts) SENSITIVE = [] include Aws::Structure end |