Class: Aws::Macie2::Types::RevealConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::RevealConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies the status of the Amazon Macie configuration for retrieving occurrences of sensitive data reported by findings, and the Key Management Service (KMS) key to use to encrypt sensitive data that’s retrieved. When you enable the configuration for the first time, your request must specify an KMS key. Otherwise, an error occurs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #kms_key_id ⇒ String
-
#status ⇒ String
The status of the configuration for retrieving occurrences of sensitive data reported by findings.
Instance Attribute Details
#kms_key_id ⇒ String
5267 5268 5269 5270 5271 5272 |
# File 'lib/aws-sdk-macie2/types.rb', line 5267 class RevealConfiguration < Struct.new( :kms_key_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the configuration for retrieving occurrences of sensitive data reported by findings. Valid values are:
5267 5268 5269 5270 5271 5272 |
# File 'lib/aws-sdk-macie2/types.rb', line 5267 class RevealConfiguration < Struct.new( :kms_key_id, :status) SENSITIVE = [] include Aws::Structure end |