Class: Aws::Macie2::Types::S3Destination
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::S3Destination
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Specifies an S3 bucket to store data classification results in, and the encryption settings to use when storing results in that bucket. The bucket must be an existing general purpose bucket. It can be a bucket in your own account or a bucket that another account owns. If another account owns the bucket, you must specify both the unique identifier for the account and the name of the bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#bucket_name ⇒ String
5479 5480 5481 5482 5483 5484 5485 5486 |
# File 'lib/aws-sdk-macie2/types.rb', line 5479 class S3Destination < Struct.new( :bucket_name, :expected_bucket_owner, :key_prefix, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
5479 5480 5481 5482 5483 5484 5485 5486 |
# File 'lib/aws-sdk-macie2/types.rb', line 5479 class S3Destination < Struct.new( :bucket_name, :expected_bucket_owner, :key_prefix, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#key_prefix ⇒ String
5479 5480 5481 5482 5483 5484 5485 5486 |
# File 'lib/aws-sdk-macie2/types.rb', line 5479 class S3Destination < Struct.new( :bucket_name, :expected_bucket_owner, :key_prefix, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
5479 5480 5481 5482 5483 5484 5485 5486 |
# File 'lib/aws-sdk-macie2/types.rb', line 5479 class S3Destination < Struct.new( :bucket_name, :expected_bucket_owner, :key_prefix, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |