Class: Aws::Macie2::Types::S3Object
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::S3Object
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the S3 object that a finding applies to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #bucket_arn ⇒ String
- #e_tag ⇒ String
- #extension ⇒ String
- #key ⇒ String
- #last_modified ⇒ Time
- #path ⇒ String
- #public_access ⇒ Boolean
-
#server_side_encryption ⇒ Types::ServerSideEncryption
Provides information about the default server-side encryption settings for an S3 bucket or the encryption settings for an S3 object.
- #size ⇒ Integer
-
#storage_class ⇒ String
The storage class of the S3 object.
-
#tags ⇒ Array<Types::KeyValuePair>
Provides information about the tags that are associated with an S3 bucket or object.
- #version_id ⇒ String
Instance Attribute Details
#bucket_arn ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#e_tag ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#extension ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#public_access ⇒ Boolean
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#server_side_encryption ⇒ Types::ServerSideEncryption
Provides information about the default server-side encryption settings for an S3 bucket or the encryption settings for an S3 object.
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#size ⇒ Integer
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
The storage class of the S3 object. Possible values are:
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::KeyValuePair>
Provides information about the tags that are associated with an S3 bucket or object. Each tag consists of a required tag key and an associated tag value.
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-macie2/types.rb', line 5568 class S3Object < Struct.new( :bucket_arn, :e_tag, :extension, :key, :last_modified, :path, :public_access, :server_side_encryption, :size, :storage_class, :tags, :version_id) SENSITIVE = [] include Aws::Structure end |