Method: Aws::Macie2::Types::UpdateRevealConfigurationRequest#configuration
- Defined in:
- lib/aws-sdk-macie2/types.rb
#configuration ⇒ Types::RevealConfiguration
Specifies the status of the Amazon Macie configuration for retrieving occurrences of sensitive data reported by findings, and the Key Management Service (KMS) key to use to encrypt sensitive data that’s retrieved. When you enable the configuration for the first time, your request must specify an KMS key. Otherwise, an error occurs.
6870 6871 6872 6873 6874 6875 |
# File 'lib/aws-sdk-macie2/types.rb', line 6870 class UpdateRevealConfigurationRequest < Struct.new( :configuration, :retrieval_configuration) SENSITIVE = [] include Aws::Structure end |