Class: Aws::Macie2::Types::UserIdentity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::UserIdentity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about the type and other characteristics of an entity that performed an action on an affected resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assumed_role ⇒ Types::AssumedRole
Provides information about an identity that performed an action on an affected resource by using temporary security credentials.
-
#aws_account ⇒ Types::AwsAccount
Provides information about an Amazon Web Services account and entity that performed an action on an affected resource.
-
#aws_service ⇒ Types::AwsService
Provides information about an Amazon Web Services service that performed an action on an affected resource.
-
#federated_user ⇒ Types::FederatedUser
Provides information about an identity that performed an action on an affected resource by using temporary security credentials.
-
#iam_user ⇒ Types::IamUser
Provides information about an Identity and Access Management (IAM) user who performed an action on an affected resource.
-
#root ⇒ Types::UserIdentityRoot
Provides information about an Amazon Web Services account and entity that performed an action on an affected resource.
-
#type ⇒ String
The type of entity that performed the action on the affected resource.
Instance Attribute Details
#assumed_role ⇒ Types::AssumedRole
Provides information about an identity that performed an action on an affected resource by using temporary security credentials. The credentials were obtained using the AssumeRole operation of the Security Token Service (STS) API.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#aws_account ⇒ Types::AwsAccount
Provides information about an Amazon Web Services account and entity that performed an action on an affected resource. The action was performed using the credentials for an Amazon Web Services account other than your own account.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#aws_service ⇒ Types::AwsService
Provides information about an Amazon Web Services service that performed an action on an affected resource.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#federated_user ⇒ Types::FederatedUser
Provides information about an identity that performed an action on an affected resource by using temporary security credentials. The credentials were obtained using the GetFederationToken operation of the Security Token Service (STS) API.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#iam_user ⇒ Types::IamUser
Provides information about an Identity and Access Management (IAM) user who performed an action on an affected resource.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#root ⇒ Types::UserIdentityRoot
Provides information about an Amazon Web Services account and entity that performed an action on an affected resource. The action was performed using the credentials for your Amazon Web Services account.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of entity that performed the action on the affected resource. Possible values are:
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/aws-sdk-macie2/types.rb', line 7146 class UserIdentity < Struct.new( :assumed_role, :aws_account, :aws_service, :federated_user, :iam_user, :root, :type) SENSITIVE = [] include Aws::Structure end |