Class: Aws::Macie2::Types::UserIdentityRoot
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie2::Types::UserIdentityRoot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie2/types.rb
Overview
Provides information about an Amazon Web Services account and entity that performed an action on an affected resource. The action was performed using the credentials for your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#account_id ⇒ String
7173 7174 7175 7176 7177 7178 7179 |
# File 'lib/aws-sdk-macie2/types.rb', line 7173 class UserIdentityRoot < Struct.new( :account_id, :arn, :principal_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
7173 7174 7175 7176 7177 7178 7179 |
# File 'lib/aws-sdk-macie2/types.rb', line 7173 class UserIdentityRoot < Struct.new( :account_id, :arn, :principal_id) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
7173 7174 7175 7176 7177 7178 7179 |
# File 'lib/aws-sdk-macie2/types.rb', line 7173 class UserIdentityRoot < Struct.new( :account_id, :arn, :principal_id) SENSITIVE = [] include Aws::Structure end |